@@ -42,6 +42,8 @@
 #include "tosql.h"
 #include "totool.h"
 
+#include "tora_toad.h"
+
 #ifndef WIN32
 #include <unistd.h>
 #endif
@@ -51,7 +53,8 @@
 #include <time.h>
 
 #ifdef TO_KDE
-#include <kapp.h>
+#include <kcmdlineargs.h>
+#include <kapplication.h>
 #endif
 
 #include <qapplication.h>
@@ -85,7 +88,8 @@ int main(int argc,char **argv)
 #endif
 
 #ifdef TO_KDE
-  new KApplication(argc,argv,"tora");
+  KCmdLineArgs::init(argc, argv, "tora", "tora", "Toolkit for Oracle", TOVERSION);
+  new KApplication;
 #else
 #  ifndef WIN32
   if (toTool::globalConfig(CONF_DESKTOP_AWARE,"Yes").isEmpty())
@@ -102,6 +106,12 @@ int main(int argc,char **argv)
     QTranslator torats(0);
     torats.load(toPluginPath()+"/"+QString("tora_")+toTool::globalConfig(CONF_LOCALE,QTextCodec::locale()),".");
     qApp->installTranslator(&torats);
+    QTranslator toadbindings;
+    if (!toTool::globalConfig(CONF_TOAD_BINDINGS,DEFAULT_TOAD_BINDINGS).isEmpty()) {
+      if (!toadbindings.load(tora_toad,sizeof(tora_toad)))
+	printf("Internal error, couldn't load TOAD bindings");
+      qApp->installTranslator(&toadbindings);
+    }
 
 #ifdef ENABLE_STYLE
     QString style=toTool::globalConfig(CONF_STYLE,"");
@@ -218,6 +228,8 @@ int main(int argc,char **argv)
 
     toUpdateIndicateEmpty();
 
+    
+
     new toMain;
 
     int ret=qApp->exec();
