@@ -394,7 +394,7 @@ void toBackup::windowActivated(QWidget *widget)
     if (!ToolMenu) {
       ToolMenu=new QPopupMenu(this);
       ToolMenu->insertItem(QPixmap((const char **)refresh_xpm),tr("&Refresh"),
-			   this,SLOT(refresh(void)),Key_F5);
+			   this,SLOT(refresh(void)),toKeySequence(tr("F5", "Backup|Refresh")));
       toMainWidget()->menuBar()->insertItem(tr("&Backup Manager"),ToolMenu,-1,toToolMenuIndex());
     }
   } else {
