@@ -210,14 +210,17 @@ toLineChart *toBarChart::openCopy(QWidget *parent)
 				    NULL,parent?0:WDestructiveClose);
   if (!parent) {
     newWin->show();
+    newWin->raise();
+    newWin->setFocus();
+
     toMainWidget()->windowsMenu();
 
 #if QT_VERSION < 0x030100
     // This is a really ugly workaround for a Qt layout bug
     QWidget *tmp=NULL;
     QWidget *tmp2=NULL;
-    for (unsigned int i=0;i<toMainWidget()->workspace()->windowList().count();i++) {
-      QWidget *widget=toMainWidget()->workspace()->windowList().at(i);
+    for (unsigned int i=0;i<toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).count();i++) {
+      QWidget *widget=toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).at(i);
       if (newWin!=widget)
 	tmp2=widget;
       else
