@@ -51,6 +51,8 @@ class toResultCombo;
 class toResultContent;
 class toResultFilter;
 class toResultView;
+class toMySQLUser;
+class toMySQLUserAccess;
 
 class toBrowser : public toToolWidget {
   Q_OBJECT
@@ -65,8 +67,11 @@ class toBrowser : public toToolWidget {
   toBrowserFilter *Filter;
   QWidget *CurrentTop;
 
+  QToolButton *FilterButton;
+  
   toResultContent *ViewContent;
   toResultContent *TableContent;
+  toResultContent *AccessContent;
 
   std::map<QCString,toResultView *> Map;
   std::map<QCString,toResult *> SecondMap;
@@ -75,6 +80,13 @@ class toBrowser : public toToolWidget {
 
   QString schema(void);
   void enableDisableConstraints(const QString &);
+  void dropSomething(const QString &,const QString &);
+
+  QListViewItem *selectedItem();
+#ifdef TOEXTENDED_MYSQL
+  toMySQLUser *UserPanel;
+  toMySQLUserAccess *AccessPanel;
+#endif
 public:
   toBrowser(QWidget *parent,toConnection &connection);
   virtual ~toBrowser();
@@ -83,6 +95,8 @@ public:
 
   virtual void exportData(std::map<QCString,QString> &data,const QCString &prefix);
   virtual void importData(std::map<QCString,QString> &data,const QCString &prefix);
+
+  virtual bool close(bool del);
 public slots:
   void refresh(void);
   void updateTabs(void);
@@ -90,7 +104,7 @@ public slots:
   void changeTab(QWidget *tab);
   void changeSecond(void);
   void changeSecondTab(QWidget *tab);
-  void changeItem(QListViewItem *item);
+  void changeItem();
   void clearFilter(void);
   void defineFilter(void);
   void windowActivated(QWidget *widget);
@@ -99,15 +113,37 @@ public slots:
 
   void modifyTable(void);
   void addTable(void);
+  void addIndex(void);
+  void modifyConstraint(void);
+  void modifyIndex(void);
+
+  void changeType(void);
+  void dropTable(void);
+  void truncateTable(void);
+
+  void checkTable(void);
+  void optimizeTable(void);
+  void analyzeTable(void);
+  void flushPrivs(void);
+
+  void dropIndex(void);
   void fixIndexCols(void);
 
+  void changeConnection(void);
   void enableConstraints(void);
   void disableConstraints(void);
+
+  void displayIndexMenu(QPopupMenu *menu);
+  void displayTableMenu(QPopupMenu *menu);
+
+  void addUser(void);
+  void dropUser(void);
 };
 
 class toBrowseTemplate : public QObject,public toTemplateProvider {
   Q_OBJECT
 
+  QToolButton *FilterButton;
   toBrowserFilter *Filter;
   std::list<toTemplateItem *> Parents;
   bool Registered;
@@ -142,4 +178,22 @@ private slots:
   void connectionChanged(void);
 };
 
+class toBrowserTool : public toTool {
+  Q_OBJECT
+
+protected:
+  virtual char **pictureXPM(void);
+public:
+  toBrowserTool();
+  virtual const char *menuItem();
+  virtual QWidget *toolWindow(QWidget *parent,toConnection &connection);
+  virtual bool canHandle(toConnection &conn);
+  virtual void customSetup(int id);
+public slots:
+  void addTable(void);
+  void addConstraint(void);
+  void addIndex(void);
+};
+
+
 #endif
