@@ -66,7 +66,7 @@
 #include "tochartmanager.moc"
 #include "tochartsetupui.moc"
 
-#include "icons/grid.xpm"
+#include "icons/chart.xpm"
 #include "icons/fileopen.xpm"
 #include "icons/refresh.xpm"
 
@@ -85,16 +85,17 @@ public:
     if (!Window) {
       Window=new toChartManager(toMainWidget()->workspace());
       Window->setCaption(qApp->translate("toChartTool","Chart Manager"));
-      Window->setIcon(QPixmap((const char **)grid_xpm));
+      Window->setIcon(QPixmap((const char **)chart_xpm));
     }
     Window->refresh();
     Window->show();
+    Window->raise();
     Window->setFocus();
     return Window;
   }
   virtual void customSetup(int toolid)
   {
-    toMainWidget()->editMenu()->insertItem(QPixmap((const char **)grid_xpm),
+    toMainWidget()->editMenu()->insertItem(QPixmap((const char **)chart_xpm),
 					   qApp->translate("toChartTool","Chart Manager..."),toolid);
 
     Handler=new toChartHandler();
@@ -264,7 +265,7 @@ toChartManager::toChartManager(QWidget *main)
 		  tr("Open tracker file"),
 		  this,SLOT(openChart()),
 		  toolbar);
-  new QToolButton(QPixmap((const char **)grid_xpm),
+  new QToolButton(QPixmap((const char **)chart_xpm),
 		  tr("Setup chart"),
 		  tr("Setup chart"),
 		  this,SLOT(setupChart()),
@@ -295,7 +296,8 @@ void toChartManager::windowActivated(QWidget *widget)
     if (!ToolMenu) {
       ToolMenu=new QPopupMenu(this);
       ToolMenu->insertItem(QPixmap((const char **)refresh_xpm),tr("&Refresh"),
-			   this,SLOT(refresh(void)),Key_F5);
+			   this,SLOT(refresh(void)),
+			   toKeySequence(tr("F5", "Chart Manager|Refresh")));
 
       toMainWidget()->menuBar()->insertItem(tr("&Chart Manager"),ToolMenu,-1,toToolMenuIndex());
     }
@@ -694,7 +696,7 @@ void toChartHandler::loadSettings(void)
 
 void toChartHandler::alarm(void)
 {
-  while(SignalAlarms.size()>0) {
+  while(!SignalAlarms.empty()) {
     toChartManager::alarmSignal signal=toShift(SignalAlarms);
     if (signal.Action==toChartManager::StatusMessage)
       toStatusMessage(tr("ALARM:")+signal.Chart+QString::fromLatin1(": ")+signal.Alarm+QString::fromLatin1(": ")+signal.xValue);
@@ -906,7 +908,7 @@ void toChartHandler::setupChart(toLineChart *chart)
 	    alarm.insert(alarm.end(),toChartManager::chartAlarm(item->text(0),
 								item->text(1)==tr("Persistent")));
 	  }
-	  if (alarm.size()>0)
+	  if (!alarm.empty())
 	    Alarms[name]=alarm;
 	  saveSettings();
 	}
