@@ -36,6 +36,7 @@
 
 #include "toconf.h"
 #include "toconnection.h"
+#include "tohighlightedtext.h"
 #include "tomain.h"
 #include "tosql.h"
 #include "totool.h"
@@ -86,6 +87,12 @@ toConnectionProvider::toConnectionProvider(const QCString &provider,bool add)
   (*Types)[provider]=this;
 }
 
+std::list<QString> toConnectionProvider::providedOptions(const QCString &)
+{
+  std::list<QString> ret;
+  return ret;
+}
+
 void toConnectionProvider::removeProvider(const QCString &provider)
 {
   std::map<QCString,toConnectionProvider *>::iterator i=Providers->find(provider);
@@ -129,13 +136,6 @@ void toConnectionProvider::initializeAll(void)
       (*i).second->initialize();
 }
 
-std::list<QString> toConnectionProvider::providedModes(const QCString &)
-{
-  std::list<QString> ret;
-  ret.insert(ret.end(),QString::fromLatin1("Normal"));
-  return ret;
-}
-
 toConnectionProvider &toConnectionProvider::fetchProvider(const QCString &provider)
 {
   checkAlloc();
@@ -145,9 +145,9 @@ toConnectionProvider &toConnectionProvider::fetchProvider(const QCString &provid
   return *((*i).second);
 }
 
-std::list<QString> toConnectionProvider::modes(const QCString &provider)
+std::list<QString> toConnectionProvider::options(const QCString &provider)
 {
-  return fetchProvider(provider).providedModes(provider);
+  return fetchProvider(provider).providedOptions(provider);
 }
 
 QWidget *toConnectionProvider::configurationTab(const QCString &provider,QWidget *parent)
@@ -220,6 +220,9 @@ toQValue::toQValue(const toQValue &copy)
   case stringType:
     Value.String=new QString(*copy.Value.String);
     break;
+  case binaryType:
+    Value.Array=new QByteArray(*copy.Value.Array);
+    break;
   case nullType:
     break;
   }
@@ -229,6 +232,8 @@ const toQValue &toQValue::operator = (const toQValue &copy)
 {
   if (Type==stringType)
     delete Value.String;
+  else if (Type==binaryType)
+    delete Value.Array;
 
   Type=copy.Type;
   switch(Type) {
@@ -241,12 +246,36 @@ const toQValue &toQValue::operator = (const toQValue &copy)
   case stringType:
     Value.String=new QString(*copy.Value.String);
     break;
+  case binaryType:
+    Value.Array=new QByteArray(*copy.Value.Array);
+    break;
   case nullType:
     break;
   }
   return *this;
 }
 
+bool toQValue::operator == (const toQValue &val) const
+{
+  if (isNull()&&val.isNull())
+    return true;
+  if (val.Type!=Type)
+    return false;
+  switch (Type) {
+  case intType:
+    return (val.Value.Int==Value.Int);
+  case doubleType:
+    return (val.Value.Double==Value.Double);
+  case stringType:
+    return (*val.Value.String)==(*Value.String);
+  case binaryType:
+    return (*val.Value.Array)==(*Value.Array);
+  case nullType:
+    break;
+  }
+  return false;		// Should never get here
+}
+
 toQValue::toQValue(const QString &str)
 {
   Type=stringType;
@@ -262,6 +291,8 @@ toQValue::~toQValue()
 {
   if (Type==stringType)
     delete Value.String;
+  else if (Type==binaryType)
+    delete Value.Array;
 }
 
 bool toQValue::isInt(void) const
@@ -279,6 +310,11 @@ bool toQValue::isString(void) const
   return Type==stringType;
 }
 
+bool toQValue::isBinary(void) const
+{
+  return Type==binaryType;
+}
+
 bool toQValue::isNull(void) const
 {
   if (Type==nullType)
@@ -288,7 +324,16 @@ bool toQValue::isNull(void) const
   return false;
 }
 
-QCString toQValue::utf8Value(void) const
+const QByteArray &toQValue::toByteArray() const
+{
+  if (Type!=binaryType)
+    throw qApp->translate("toQValue","Tried to convert non binary value to binary");
+  return *Value.Array;
+}
+
+static char HexString[]="0123456789ABCDEF";
+
+QCString toQValue::utf8(void) const
 {
   switch(Type) {
   case nullType:
@@ -327,6 +372,17 @@ QCString toQValue::utf8Value(void) const
     }
   case stringType:
     return Value.String->utf8();
+  case binaryType:
+    {
+      QCString ret(Value.Array->size()*2+1);
+      for(unsigned int i=0;i<Value.Array->size();i++) {
+	unsigned char c=(unsigned char)Value.Array->at(i);
+	ret.at(i*2)=HexString[(c/16)%16];
+	ret.at(i*2+1)=HexString[c%16];
+      }
+      ret.at(Value.Array->size()*2)=0;
+      return ret;
+    }
   }
   throw qApp->translate("toQValue","Unknown type of query value");
 }
@@ -342,6 +398,8 @@ int toQValue::toInt(void) const
     return int(Value.Double);
   case stringType:
     return Value.String->toInt();
+  case binaryType:
+    throw qApp->translate("toQValue","Can't transform binary value to int");
   }
   throw qApp->translate("toQValue","Unknown type of query value");
 }
@@ -357,6 +415,8 @@ double toQValue::toDouble(void) const
     return Value.Double;
   case stringType:
     return Value.String->toDouble();
+  case binaryType:
+    throw qApp->translate("toQValue","Can't transform binary value to double");
   }
   throw qApp->translate("toQValue","Unknown type of query value");
 }
@@ -399,6 +459,64 @@ int toQValue::numberDecimals(void)
   return NumberDecimals;
 }
 
+toQValue toQValue::createBinary(const QByteArray &arr)
+{
+  toQValue ret;
+  ret.Type=binaryType;
+  ret.Value.Array=new QByteArray(arr);
+  return ret;
+}
+
+toQValue toQValue::createFromHex(const QCString &hex)
+{
+  QByteArray arr((hex.length()+1)/2);
+  for(unsigned int i=0;i<hex.length();i+=2) {
+    int num;
+    char c=hex.at(i);
+    if (c>='a')
+      num=c-'a';
+    else if (c>='A')
+      num=c-'A';
+    else
+      num=c-'0';
+    num<<=4;
+    c=hex.at(i+1);
+    if (c>='a')
+      num+=c-'a';
+    else if (c>='A')
+      num+=c-'A';
+    else
+      num+=c-'0';
+    arr.at(i/2)=num;
+  }
+  return createBinary(arr);
+}
+
+toQValue toQValue::createFromHex(const QString &hex)
+{
+  QByteArray arr((hex.length()+1)/2);
+  for(unsigned int i=0;i<hex.length();i+=2) {
+    int num;
+    char c=hex.at(i);
+    if (c>='a')
+      num=c-'a';
+    else if (c>='A')
+      num=c-'A';
+    else
+      num=c-'0';
+    num<<=4;
+    c=hex.at(i+1);
+    if (c>='a')
+      num+=c-'a';
+    else if (c>='A')
+      num+=c-'A';
+    else
+      num+=c-'0';
+    arr.at(i/2)=num;
+  }
+  return createBinary(arr);
+}
+
 toQValue::operator QString() const
 {
   switch(Type) {
@@ -410,6 +528,16 @@ toQValue::operator QString() const
     return QString::number(Value.Int);
   case stringType:
     return *Value.String;
+  case binaryType:
+    {
+      QString ret;
+      for(unsigned int i=0;i<Value.Array->size();i++) {
+	unsigned char c=(unsigned char)Value.Array->at(i);
+	ret+=HexString[(c/16)%16];
+	ret+=HexString[c%16];
+      }
+      return ret;
+    }
   }
   throw qApp->translate("toQValue","Unknown type of query value");
 }
@@ -872,9 +1000,9 @@ void toConnection::addConnection(void)
   toLocker lock(Lock);
   Connections.insert(Connections.end(),sub);
   toQList params;
-  for(std::list<QCString>::iterator i=InitStrings.begin();i!=InitStrings.end();i++) {
+  for(std::list<QString>::iterator i=InitStrings.begin();i!=InitStrings.end();i++) {
     try {
-      Connection->execute(sub,*i,params);
+      Connection->execute(sub,(*i).utf8(),params);
     } TOCATCH
   }
 }
@@ -882,8 +1010,8 @@ void toConnection::addConnection(void)
 toConnection::toConnection(const QCString &provider,
 			   const QString &user,const QString &password,
 			   const QString &host,const QString &database,
-			   const QString &mode,bool cache)
-  : Provider(provider),User(user),Password(password),Host(host),Database(database),Mode(mode)
+			   const std::set<QString> &options,bool cache)
+  : Provider(provider),User(user),Password(password),Host(host),Database(database),Options(options)
 {
   BackgroundConnection=NULL;
   BackgroundCount=0;
@@ -893,7 +1021,7 @@ toConnection::toConnection(const QCString &provider,
   NeedCommit=Abort=false;
   ReadingCache=false;
   if (cache) {
-    if (toTool::globalConfig(CONF_OBJECT_CACHE,"0").toInt()==1)
+    if (toTool::globalConfig(CONF_OBJECT_CACHE,DEFAULT_OBJECT_CACHE).toInt()==1)
       readObjects();
   } else {
     ReadingValues.up();
@@ -907,7 +1035,7 @@ toConnection::toConnection(const toConnection &conn)
     Password(conn.Password),
     Host(conn.Host),
     Database(conn.Database),
-    Mode(conn.Database)
+    Options(conn.Options)
 {
   BackgroundConnection=NULL;
   BackgroundCount=0;
@@ -1074,8 +1202,9 @@ void toConnection::rollback(void)
 {
   toBusy busy;
   toLocker lock(Lock);
-  for(std::list<toConnectionSub *>::iterator i=Connections.begin();i!=Connections.end();i++)
+  for(std::list<toConnectionSub *>::iterator i=Connections.begin();i!=Connections.end();i++) {
     Connection->rollback(*i);
+  }
   while(Connections.size()>2) {
     std::list<toConnectionSub *>::iterator i=Connections.begin();
     i++;
@@ -1134,22 +1263,25 @@ QString toConnection::description(bool version) const
 void toConnection::addInit(const QString &sql)
 {
   delInit(sql);
-  InitStrings.insert(InitStrings.end(),sql.utf8());
+  InitStrings.insert(InitStrings.end(),sql);
 }
 
 void toConnection::delInit(const QString &sql)
 {
-  QCString utf=sql.utf8();
-  std::list<QCString>::iterator i=InitStrings.begin();
+  std::list<QString>::iterator i=InitStrings.begin();
   while (i!=InitStrings.end()) {
-    if ((*i)==utf) {
-      InitStrings.erase(i);
-      i=InitStrings.begin();
-    } else
+    if ((*i)==sql) 
+      i=InitStrings.erase(i);
+    else
       i++;
   }
 }
 
+const std::list<QString> &toConnection::initStrings() const
+{
+  return InitStrings;
+}
+
 void toConnection::parse(const QString &sql)
 {
   toBusy busy;
@@ -1423,26 +1555,48 @@ const QCString &toConnection::provider(void) const
   return Provider;
 }
 
+QString toConnection::cacheDir()
+{
+   QString home=QDir::homeDirPath();
+   QString dirname = toTool::globalConfig(CONF_CACHE_DIR, "");
+
+   if (dirname.isEmpty()) {
+#ifdef WIN32
+     if (getenv("TEMP"))
+       dirname=QString(getenv("TEMP"));
+     else
+#endif
+       dirname=QString(home);
+#ifdef TOAD
+     dirname+="/.toad_cache";
+#else
+     dirname+="/.tora_cache";
+#endif
+   }
+   return dirname;
+}
+
+QString toConnection::cacheFile()
+{
+   QString dbname (description(false).stripWhiteSpace());
+
+   return (cacheDir()+"/"+dbname).simplifyWhiteSpace();
+}
+
 bool toConnection::loadDiskCache() 
 {
-   if (toTool::globalConfig(CONF_CACHE_DISK,"No") == "No")
+   if (toTool::globalConfig(CONF_CACHE_DISK,DEFAULT_CACHE_DISK).isEmpty())
    	return false;
 
    toConnection::objectName *cur;
    int objCounter = 0;
    int synCounter = 0;
-   
-   QString dbname (Database.stripWhiteSpace());
-   QString home=QDir::homeDirPath();
-   QString dirname = toTool::globalConfig(CONF_CACHE_DIR, "");
 
-   if (dirname == "")
-       dirname = QString(home+"/.tora_cache");
+   QString filename=cacheFile();
 
-   QString filename(dirname+"/"+dbname);
-   QFile file(filename.stripWhiteSpace());
+   QFile file(filename);
 
-   if (!QFile::exists(filename.stripWhiteSpace())) 
+   if (!QFile::exists(filename))
      return false;
 
    QFileInfo fi(file);
@@ -1492,20 +1646,16 @@ void toConnection::writeDiskCache()
   long objCounter = 0;
   long synCounter = 0;
 
-  if (toTool::globalConfig(CONF_CACHE_DISK,"No") == "No")
+  if (toTool::globalConfig(CONF_CACHE_DISK,DEFAULT_CACHE_DISK).isEmpty())
    	return;
 
 
-  QString dbname (Database.stripWhiteSpace());
-  QString home=QDir::homeDirPath();
-  QString dirname = toTool::globalConfig(CONF_CACHE_DIR, "");
-  if (dirname == "")
-    dirname = QString(home+"/.tora_cache");
-  QString filename(dirname+"/"+dbname);
+  QString filename(cacheFile());
 	
   /** check pathnames and create
    */
 
+  QString dirname(cacheDir());
   QDir dir;
   dir.setPath(dirname);
 
@@ -1536,7 +1686,7 @@ void toConnection::writeDiskCache()
   }
   /** open file
    */  
-  QFile file(filename.stripWhiteSpace());	
+  QFile file(filename);
   file.open( IO_ReadWrite  | IO_Truncate );
   QTextStream t (&file);
   t << records.join("\x1D");
@@ -1568,7 +1718,7 @@ void toConnection::cacheObjects::run()
 
 void toConnection::readObjects(void)
 {
-  if (toTool::globalConfig(CONF_OBJECT_CACHE,"0").toInt()==3) {
+  if (toTool::globalConfig(CONF_OBJECT_CACHE,DEFAULT_OBJECT_CACHE).toInt()==3) {
     ReadingCache=false;
     return;
   } 
@@ -1586,7 +1736,7 @@ void toConnection::readObjects(void)
 void toConnection::rereadCache(void)
 {
 
-  if (toTool::globalConfig(CONF_OBJECT_CACHE,"0").toInt()==3) {
+  if (toTool::globalConfig(CONF_OBJECT_CACHE,DEFAULT_OBJECT_CACHE).toInt()==3) {
     ColumnCache.clear();
     return;
   }
@@ -1609,16 +1759,10 @@ void toConnection::rereadCache(void)
   /** delete cache file to force reload
    */
 
-  QString home=QDir::homeDirPath();
-  QString dirname = toTool::globalConfig(CONF_CACHE_DIR, "");
-  QString dbname (Database.stripWhiteSpace());
+  QString filename(cacheFile());
 
-  if (dirname == "")
-    dirname = QString(home+"/.tora_cache");
-  QString filename(dirname+"/"+dbname);
-
-  if (QFile::exists(filename.stripWhiteSpace())) 
-    QFile::remove(filename.stripWhiteSpace());
+  if (QFile::exists(filename)) 
+    QFile::remove(filename);
  
   readObjects();
 }
@@ -1635,13 +1779,13 @@ QString toConnection::unQuote(const QString &name)
 
 bool toConnection::cacheAvailable(bool synonyms,bool block,bool need)
 {
-  if (toTool::globalConfig(CONF_OBJECT_CACHE,"0").toInt()==3)
+  if (toTool::globalConfig(CONF_OBJECT_CACHE,DEFAULT_OBJECT_CACHE).toInt()==3)
       return true;
 
   if (!ReadingCache) {
     if (!need)
       return true;
-    if (toTool::globalConfig(CONF_OBJECT_CACHE,"0").toInt()==2&&!block)
+    if (toTool::globalConfig(CONF_OBJECT_CACHE,DEFAULT_OBJECT_CACHE).toInt()==2&&!block)
       return true;
     readObjects();
     toMainWidget()->checkCaching();
@@ -1809,6 +1953,16 @@ bool toConnection::objectName::operator == (const objectName &nam) const
   return Owner==nam.Owner&&Name==nam.Name&&Type==nam.Type;
 }
 
+toSyntaxAnalyzer &toConnection::connectionImpl::analyzer()
+{
+  return toSyntaxAnalyzer::defaultAnalyzer();
+}
+
+toSyntaxAnalyzer &toConnection::analyzer()
+{
+  return Connection->analyzer();
+}
+
 std::list<toConnection::objectName> toConnection::connectionImpl::objectNames(void)
 {
   std::list<toConnection::objectName> ret;
