@@ -40,6 +40,7 @@
 
 #include <list>
 #include <map>
+#include <set>
 
 #include <qstring.h>
 
@@ -48,6 +49,7 @@ class toConnection;
 class toConnectionProvider;
 class toSQL;
 class toQuery;
+class toSyntaxAnalyzer;
 
 /** This class is an abstract definition of an actual connection to a database.
  * Each @ref toConnection object can have one or more actual connections to the
@@ -412,10 +414,10 @@ class toConnection {
   QString Password;
   QString Host;
   QString Database;
-  QString Mode;
   QCString Version;
   std::list<QObject *> Widgets;
-  std::list<QCString> InitStrings;
+  std::list<QString> InitStrings;
+  std::set<QString> Options;
   toLock Lock;
   std::list<toConnectionSub *> Connections;
   std::list<toConnectionSub *> Running;
@@ -466,6 +468,16 @@ public:
     */
     std::list <QString> Synonyms;
 
+    /** Create an object name with filled in values.
+     */
+    objectName(const QString &owner,const QString &name,const QString &type=QString("TABLE"),const QString &comment=QString::null)
+      : Name(name),Owner(owner),Type(type),Comment(comment)
+    { }
+
+    /** Create an empty object name.
+     */
+    objectName()
+    { }
     bool operator < (const objectName &) const;
     bool operator == (const objectName &) const;
   };
@@ -528,6 +540,12 @@ public:
     virtual QString unQuote(const QString &name)
     { return name; }
 
+    /**
+     * Get syntax analyzer for connection
+     * @return A reference to the syntax analyzer to use for the connection.
+     */
+    virtual toSyntaxAnalyzer &analyzer();
+
     /** Extract available objects to query for connection. Any access to the
      * database should always be run using a long running query. If something
      * goes wrong should throw exception.
@@ -597,6 +615,8 @@ private:
   toConnectionSub *backgroundConnection(void);
   void freeConnection(toConnectionSub *);
   void readObjects(void);
+
+  QString cacheFile();
 public:
   /** Create a new connection.
    * @param provider Which database provider to use for this connection.
@@ -605,11 +625,11 @@ public:
    * @param password Password to connect with.
    * @param host Host to connect to the database with.
    * @param database Database to connect to.
-   * @param mode Mode to connect to the database with.
+   * @param options Options used to connect to the database with.
    * @param cache Enable object cache for this connection.
    */
   toConnection(const QCString &provider,const QString &user,const QString &password,
-	       const QString &host,const QString &database,const QString &mode=QString::null,
+	       const QString &host,const QString &database,const std::set<QString> &options,
 	       bool cache=true);
   /** Create a copy of a connection. Will not cache objects, so objects will never be available
    *  in a subconnection.
@@ -620,6 +640,9 @@ public:
    */
   virtual ~toConnection();
 
+  //* Get the options for the connection.
+  const std::set<QString> &options() const
+  { return Options; }
   /** Try to close all the widgets associated with this connection.
    * @return True if all widgets agreed to close.
    */
@@ -644,10 +667,6 @@ public:
    */
   const QString &database() const
   { return Database; }
-  /** Get mode of connection.
-   */
-  const QString &mode() const
-  { return Mode; }
   /** Get version of connection.
    */
   const QCString &version() const
@@ -656,6 +675,12 @@ public:
    */
   const QCString &provider() const;
 
+  /** Change the current database. Observe that this only changes the record of what is the current database. You will still need
+   * to change the database oppinion on what database is the current one.
+   */
+  void setDatabase(const QString &database)
+  { Database=database; }
+
   /** Get a description of this connection.
    * @version Include version in returned string.
    */
@@ -787,6 +812,10 @@ public:
    * Remove a statement that was added using @ref addInit.
    */
   void delInit(const QString &sql);
+  /**
+   * Get a list of the current init strings.
+   */
+  const std::list<QString> &toConnection::initStrings() const;
 
   /** Return a string representation to address an object.
    * @param name The name to be quoted.
@@ -812,6 +841,12 @@ public:
    */
   void addIfNotExists(objectName &object);
 
+  /**
+   * Get syntax analyzer for connection
+   * @return A reference to the syntax analyzer to use for the connection.
+   */
+  virtual toSyntaxAnalyzer &analyzer();
+
   /**
    * Get the synonyms available for objects. Do not modify the returned list.
    * @param block Indicate wether or not to block until cached objects are available.
@@ -869,7 +904,7 @@ public:
    */
   std::list<QString> running(void);
 
-  void logMessage(QString text);
+  static QString cacheDir();
   
   friend class toQuery;
 };
@@ -905,14 +940,12 @@ public:
   virtual ~toConnectionProvider();
 
   /** Create an implementation of a connection to this database.
+   * @param provider Provider to use for connection.
+   * @param conn The connection object to use the created connection.
    * @return A connection implementation created with new.
    */
   virtual toConnection::connectionImpl *provideConnection(const QCString &provider,
 							  toConnection *conn)=0;
-  /** List the available modes for this database.
-   * @return A list of modes that the connection implementation understands.
-   */
-  virtual std::list<QString> providedModes(const QCString &provider);
   /** List the available hosts this database provider knows about.
    * @return A list of hosts.
    */
@@ -933,6 +966,13 @@ public:
   virtual void initialize(void)
   { }
 
+  /** Get a list of options available for the connection. An option with the name
+   * "-" indicates a break should be made to separate the rest of the options from the previous
+   * options. An option preceeded by "*" means selected by default. The * shoul be stripped before
+   * before passing it to the connection call.
+   */
+  virtual std::list<QString> providedOptions(const QCString &provider);
+
   /**
    * Create and return configuration tab for this connectiontype. The returned widget should also
    * be a childclass of @ref toSettingTab.
@@ -948,9 +988,9 @@ public:
   /** Get a list of names for providers.
    */
   static std::list<QCString> providers();
-  /** Get a list of modes for a given provider.
+  /** Get a list of options for a given provider.
    */
-  static std::list<QString> modes(const QCString &provider);
+  static std::list<QString> options(const QCString &provider);
   /** Implement a connection for a given provider.
    * @param provider Provider to implement.
    * @param conn Connection to create implementation for.
