@@ -128,8 +128,10 @@ toInvalid::toInvalid(QWidget *main,toConnection &connection)
   Objects=new toResultLong(false,false,toQuery::Background,splitter);
   Objects->setSQL(SQLListInvalid);
 
-  Objects->setSelectionMode(QListView::Single);
+  Objects->setSelectionMode(QListView::Extended);
   connect(Objects,SIGNAL(selectionChanged()),this,SLOT(changeSelection()));
+  connect(Objects,SIGNAL(currentChanged(QListViewItem *)),
+	  this,SLOT(changeSelection()));
 
   Source=new toResultExtract(false,splitter);
   Source->setSQL(SQLListSource);
@@ -173,6 +175,8 @@ void toInvalid::recompileSelected(void)
       QString sql;
       if (type=="INDEX")
 	sql="ALTER "+ci->allText(2)+" "+conn.quote(ci->allText(0))+"."+conn.quote(ci->allText(1))+" REBUILD";
+      else if (type=="PACKAGE BODY")
+	sql="ALTER PACKAGE "+conn.quote(ci->allText(0))+"."+conn.quote(ci->allText(1))+" COMPILE BODY REUSE SETTINGS";
       else
 	sql="ALTER "+ci->allText(2)+" "+conn.quote(ci->allText(0))+"."+conn.quote(ci->allText(1))+" COMPILE REUSE SETTINGS";
       try {
@@ -191,7 +195,8 @@ void toInvalid::windowActivated(QWidget *widget)
     if (!ToolMenu) {
       ToolMenu=new QPopupMenu(this);
       ToolMenu->insertItem(QPixmap((const char **)refresh_xpm),tr("&Refresh"),
-			   this,SLOT(refresh(void)),Key_F5);
+			   this,SLOT(refresh(void)),
+			   toKeySequence(tr("F5", "Invalid|Refresh")));
 
       toMainWidget()->menuBar()->insertItem(tr("&Invalid"),ToolMenu,-1,toToolMenuIndex());
     }
