@@ -59,7 +59,7 @@
 #include "tolinechartsetupui.moc"
 
 #include "icons/print.xpm"
-#include "icons/grid.xpm"
+#include "icons/chart.xpm"
 
 double toLineChart::round(double round,bool up)
 {
@@ -109,7 +109,7 @@ void toLineChart::setSamples(int samples)
 toLineChart::toLineChart(QWidget *parent,const char *name,WFlags f)
   : QWidget(parent,name,f)
 {
-  setIcon(QPixmap((const char**)grid_xpm));
+  setIcon(QPixmap((const char**)chart_xpm));
   Menu=NULL;
   MinAuto=MaxAuto=true;
   MinValue=MaxValue=0;
@@ -748,14 +748,16 @@ toLineChart *toLineChart::openCopy(QWidget *parent)
 				      NULL,parent?0:WDestructiveClose);
   if (!parent) {
     newWin->show();
+    newWin->raise();
+    newWin->setFocus();
     toMainWidget()->windowsMenu();
 
 #if QT_VERSION < 0x030100
     // This is a really ugly workaround for a Qt layout bug
     QWidget *tmp=NULL;
     QWidget *tmp2=NULL;
-    for (unsigned int i=0;i<toMainWidget()->workspace()->windowList().count();i++) {
-      QWidget *widget=toMainWidget()->workspace()->windowList().at(i);
+    for (unsigned int i=0;i<toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).count();i++) {
+      QWidget *widget=toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).at(i);
       if (newWin!=widget)
 	tmp2=widget;
       else
@@ -799,7 +801,7 @@ toLineChart::toLineChart (toLineChart *chart,QWidget *parent,const char *name,WF
   Enabled=chart->Enabled;
 
   setCaption(Title);
-  setIcon(QPixmap((const char**)grid_xpm));
+  setIcon(QPixmap((const char**)chart_xpm));
 
   clearZoom();
 
