@@ -76,13 +76,13 @@
 static int toMaxLong=DEFAULT_MAX_LONG;
 
 static toSQL SQLComment("toOracleConnection:Comments",
-			"SELECT Column_name,Comments FROM sys.All_Col_Comments\n"
+			"SELECT /*+ RULE */ Column_name,Comments FROM sys.All_Col_Comments\n"
 			" WHERE Owner = :f1<char[100]>\n"
 			"   AND Table_Name = :f2<char[100]>",
 			"Display column comments");
 
 static toSQL SQLMembers("toOracleConnection:Members",
-			"SELECT object_name,overload,argument_name,data_type\n"
+			"SELECT /*+ RULE */ object_name,overload,argument_name,data_type\n"
 			"  FROM sys.All_Arguments\n"
 			" WHERE Owner = :f1<char[100]>\n"
 			"   AND Package_Name = :f2<char[100]>\n"
@@ -90,7 +90,7 @@ static toSQL SQLMembers("toOracleConnection:Members",
 			"Get list of package members");
 
 static toSQL SQLListObjects("toOracleConnection:ListObjects",
-			    "select a.owner,a.object_name,a.object_type,b.comments\n"
+			    "select /*+ RULE */ a.owner,a.object_name,a.object_type,b.comments\n"
 			    "  from sys.all_objects a,\n"
 			    "       sys.all_tab_comments b\n"
 			    " where a.owner = b.owner(+) and a.object_name = b.table_name(+)\n"
@@ -99,7 +99,7 @@ static toSQL SQLListObjects("toOracleConnection:ListObjects",
 			    "columns and binds");
 
 static toSQL SQLListSynonyms("toOracleConnection:ListSynonyms",
-			     "select synonym_name,table_owner,table_name\n"
+			     "select /*+ RULE */ synonym_name,table_owner,table_name\n"
 			     "  from sys.all_synonyms\n"
 			     " where owner = :usr<char[101]> or owner = 'PUBLIC'\n"
 			     " order by table_owner,table_name",
@@ -260,7 +260,7 @@ public:
 	    int len=toMaxLong;
 	    if (toMaxLong<0)
 	      len=DEFAULT_MAX_LONG;
-	    buffer=new char[len+1];
+	    buffer=(char *)malloc(len+1);
 	    buffer[len]=0;
 	    otl_long_string str(buffer,len);
 	    (*Query)>>str;
@@ -268,9 +268,16 @@ public:
 	    conn->Lock.up();
 	    if (!str.len())
 	      return null;
-	    QString buf(QString::fromUtf8(buffer));
-	    delete[] buffer;
-	    return buf;
+	    QString buf;
+	    if (dsc->ftype==otl_var_varchar_long) {
+	      buf=(QString::fromUtf8(buffer));
+	      free(buffer);
+	      return buf;
+	    } else {
+	      QByteArray ret;
+	      ret.assign(buffer,str.len());
+	      return toQValue::createBinary(ret);
+	    }
 	  }
 	case otl_var_clob:
 	case otl_var_blob:
@@ -289,7 +296,7 @@ public:
 	      len*=5;
 	    else
 	      len*=2;
-	    buffer=new char[len+1];
+	    buffer=(char *)malloc(len+1);
 	    buffer[0]=0;
 	    otl_long_string data(buffer,len);
 	    lob>>data;
@@ -304,21 +311,18 @@ public:
 		printf("Data exists past length of LOB in thread\n");
 	    }
 	    buffer[data.len()]=0;
-	    QString buf;
-	    if (dsc->ftype==otl_var_clob)
-	      buf=QString::fromUtf8(buffer);
-	    else {
-	      buf.fill('0',data.len()*2);
-	      QString t;
-	      for(int i=0;i<data.len();i++) {
-		t.sprintf("%02x",((unsigned int)buffer[i])%0xff);
-		buf.replace(i*2,2,t);
-	      }
-	    }
-	    delete[] buffer;
 	    Running=false;
 	    conn->Lock.up();
-	    return buf;
+
+	    if (dsc->ftype==otl_var_clob) {
+	      QString buf=QString::fromUtf8(buffer);
+	      free(buffer);
+	      return buf;
+	    } else {
+	      QByteArray ret;
+	      ret.assign(buffer,data.len());
+	      return toQValue::createBinary(ret);
+	    }
 	  }
 	  break;
 	default:  // Try using char if all else fails
@@ -684,7 +688,7 @@ public:
 	otl_stream version(1,
 			   "SELECT banner FROM v$version",
 			   *(conn->Connection));
-	QRegExp verre(QString::fromLatin1("[0-9]\\.[0-9\\.]+[0-9]"));
+	QRegExp verre(QString::fromLatin1("[0-9]+\\.[0-9\\.]+[0-9]"));
 	QRegExp orare(QString::fromLatin1("^(\\S+ )?oracle"),false);
 	while(!version.eof()) {
 	  char buffer[1024];
@@ -745,12 +749,13 @@ public:
 
   virtual toConnection::connectionImpl *provideConnection(const QCString &,toConnection *conn)
   { return new oracleConnection(conn); }
-  virtual std::list<QString> providedModes(const QCString &)
+  virtual std::list<QString> providedOptions(const QCString &)
   {
     std::list<QString> ret;
-    ret.insert(ret.end(),QString::fromLatin1("Normal"));
-    ret.insert(ret.end(),QString::fromLatin1("SYS_OPER"));
-    ret.insert(ret.end(),QString::fromLatin1("SYS_DBA"));
+    ret.insert(ret.end(),"*SQL*Net");
+    ret.insert(ret.end(),"-");
+    ret.insert(ret.end(),"SYS_OPER");
+    ret.insert(ret.end(),"SYS_DBA");
     return ret;
   }
   virtual std::list<QString> providedHosts(const QCString &)
@@ -920,8 +925,25 @@ void toOracleProvider::oracleQuery::execute(void)
 	  case otl_var_long_int:
 	    (*Query)<<(*i).toInt();
 	    break;
+	  case otl_var_raw_long:
+	  case otl_var_blob:
+	    if ((*i).isBinary()) {
+	      QByteArray arr=(*i).toByteArray();
+	      otl_long_string str(arr,arr.size(),arr.size());
+	      (*Query)<<str;
+	      break;
+	    }
+	    // Intentially left out break
+	  case otl_var_varchar_long:
+	  case otl_var_clob:
+	    {
+	      QCString buf=(*i).utf8();
+	      otl_long_string str(buf,buf.length(),buf.length());
+	      (*Query)<<str;
+	    }
+	    break;
 	  default:
-	    (*Query)<<QString(*i).utf8();
+	    (*Query)<<(*i).utf8();
 	    break;
 	  }
 	} else {
@@ -954,18 +976,20 @@ void toOracleProvider::oracleQuery::cancel(void)
 toConnectionSub *toOracleProvider::oracleConnection::createConnection(void)
 {
   QString oldSid;
-  bool sqlNet=!connection().host().isEmpty();
+
+  std::set<QString> options=connection().options();
+
+  bool sqlNet=(options.find("SQL*Net")!=options.end());
   if (!sqlNet) {
     oldSid=getenv("ORACLE_SID");
     toSetEnv("ORACLE_SID",connection().database().utf8());
   }
   otl_connect *conn=NULL;
   try {
-    QString mode=connection().mode();
     int session_mode=OCI_DEFAULT;
-    if (mode==QString::fromLatin1("SYS_OPER"))
+    if (options.find("SYS_OPER")!=options.end())
       session_mode=OCI_SYSOPER;
-    else if (mode==QString::fromLatin1("SYS_DBA"))
+    else if (options.find("SYS_DBA")!=options.end())
       session_mode=OCI_SYSDBA;
     do {
       conn=new otl_connect;
