@@ -42,6 +42,7 @@
 
 #include <qapplication.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qgrid.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -54,8 +55,8 @@
 
 #include "toparamget.moc"
 
-std::map<QString,std::map<QString,QString> > toParamGet::DefaultCache;
-std::map<QString,std::map<QString,QString> > toParamGet::Cache;
+std::map<QString,std::list<QString> > toParamGet::DefaultCache;
+std::map<QString,std::list<QString> > toParamGet::Cache;
 
 toParamGet::toParamGet(QWidget *parent,const char *name)
   : QDialog(parent,name,true),toHelpContext(QString::fromLatin1("common.html#param"))
@@ -68,16 +69,17 @@ toParamGet::toParamGet(QWidget *parent,const char *name)
   layout->setSpacing( 6 );
   layout->setMargin( 11 );
 
-  QScrollView *scroll=new QScrollView(this);
-  scroll->enableClipper(true);
-  scroll->setGeometry(10,10,330,480);
-  scroll->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
-  layout->addMultiCellWidget(scroll,0,2,0,0);
+  View=new QScrollView(this);
+  View->enableClipper(true);
+  View->setGeometry(10,10,330,480);
+  View->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
+  layout->addMultiCellWidget(View,0,2,0,0);
 
-  Container=new QGrid(4,scroll->viewport());
-  scroll->addChild(Container,5,5);
+  Container=new QGrid(4,View->viewport());
+  View->addChild(Container,5,5);
   Container->setSpacing(10);
-  scroll->viewport()->setBackgroundColor(qApp->palette().active().background());
+  Container->setFixedWidth(View->width()-30);
+  View->viewport()->setBackgroundColor(qApp->palette().active().background());
 
   QPushButton *OkButton = new QPushButton(this,"OkButton");
   OkButton->setText(tr("&Ok"));
@@ -96,15 +98,12 @@ toParamGet::toParamGet(QWidget *parent,const char *name)
   connect(CancelButton,SIGNAL(clicked()),this,SLOT(reject()));
 }
 
-toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str)
+toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str,bool interactive)
 {
   std::map<QString,bool> parameters;
   std::list<QString> names;
   toParamGet *widget=NULL;
 
-  std::map<QString,QString> &cache=Cache[conn.description()];
-  std::map<QString,QString> &defaultCache=DefaultCache[conn.description()];
-
   enum {
     afterName,
     inString,
@@ -187,7 +186,7 @@ toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str)
 	  fname+=c;
 	  break;
 	}
-	if (fname.isEmpty()) {
+	if (fname.isEmpty()&&!toIsMySQL(conn)) {
 	  toStatusMessage(tr("Missing field name"));
 	  throw tr("Missing field name");
 	}
@@ -224,19 +223,29 @@ toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str)
 	  if (!widget)
 	    widget=new toParamGet(parent);
 	  new QLabel(fname,widget->Container);
-	  std::map<QString,QString>::iterator fnd=cache.find(fname);
-	  bool found=true;
-	  if (fnd==cache.end()) {
-	    fnd=defaultCache.find(fname);
-	    if (fnd==defaultCache.end())
-	      found=false;
-	  }
-	  QLineEdit *edit=new QLineEdit(widget->Container,QString::number(num));
+	  QComboBox *edit=new QComboBox(widget->Container,QString::number(num));
+	  edit->setEditable(true);
+	  QString defval;
+	  std::map<QString,std::list<QString> >::iterator fnd=Cache.find(fname);
+	  if (fnd!=Cache.end())
+	    for(std::list<QString>::iterator i=(*fnd).second.begin();i!=(*fnd).second.end();i++) {
+	      if (edit->count()==0)
+		defval=*i;
+	      edit->insertItem(*i);
+	    }
+	  
+	  fnd=DefaultCache.find(fname);
+	  if (fnd!=DefaultCache.end())
+	    for(std::list<QString>::iterator i=(*fnd).second.begin();i!=(*fnd).second.end();i++) {
+	      if (edit->count()==0)
+		defval=*i;
+	      edit->insertItem(*i);
+	    }
+
 	  QCheckBox *box=new QCheckBox(tr("NULL"),widget->Container);
 	  connect(box,SIGNAL(toggled(bool)),edit,SLOT(setDisabled(bool)));
-	  if (found) {
-	    edit->setText((*fnd).second);
-	    if ((*fnd).second.isNull())
+	  if (edit->count()>0) {
+	    if (defval.isNull())
 	      box->setChecked(true);
 	  }
 	  toParamGetButton *btn=new toParamGetButton(num,widget->Container);
@@ -258,19 +267,34 @@ toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str)
   toQList ret;
   if (widget) {
     (*widget->Value.begin())->setFocus();
-    if (widget->exec()) {
+    if (!interactive||widget->exec()) {
       std::list<QString>::iterator cn=names.begin();
-      for (std::list<QLineEdit *>::iterator i=widget->Value.begin();i!=widget->Value.end();i++) {
-	QLineEdit *current=*i;
+      for (std::list<QComboBox *>::iterator i=widget->Value.begin();i!=widget->Value.end();i++) {
+	QComboBox *current=*i;
 	QString val;
 	if (current) {
 	  if (current->isEnabled())
-	    val=current->text();
+	    val=current->currentText();
 	  else
 	    val=QString::null;
 	}
 	if (cn!=names.end()) {
-	  cache[*cn]=val;
+	  std::list<QString> &lst=Cache[*cn];
+	  for(std::list<QString>::iterator i=lst.begin();i!=lst.end();i++)
+	    if ((*i)==val) {
+	      lst.erase(i);
+	      break;
+	    }
+	  lst.insert(lst.begin(),val);
+
+	  std::map<QString,std::list<QString> >::iterator fnd=DefaultCache.find(*cn);
+	  if (fnd!=DefaultCache.find(*cn))
+	    for(std::list<QString>::iterator i=(*fnd).second.begin();i!=(*fnd).second.end();i++)
+	      if ((*i)==val) {
+		(*fnd).second.erase(i);
+		break;
+	      }
+
 	  cn++;
 	}
 	ret.insert(ret.end(),val);
@@ -286,9 +310,21 @@ toQList toParamGet::getParam(toConnection &conn,QWidget *parent,QString &str)
   return ret;
 }
 
-void toParamGet::setDefault(toConnection &conn,const QString &name,const QString &val)
+void toParamGet::setDefault(toConnection &,const QString &name,const QString &val)
 {
-  (DefaultCache[conn.description()])[name]=val;
+  std::map<QString,std::list<QString> >::iterator fnd=Cache.find(name);
+  if (fnd!=Cache.end())
+    for(std::list<QString>::iterator i=(*fnd).second.begin();i!=(*fnd).second.end();i++)
+      if (val==*i)
+	return;
+
+  std::list<QString> &lst=DefaultCache[name];
+  for(std::list<QString>::iterator i=lst.begin();i!=lst.end();i++)
+    if ((*i)==val) {
+      lst.erase(i);
+      break;
+    }
+  lst.insert(lst.begin(),val);
 }
 
 void toParamGet::showMemo(int row)
@@ -300,3 +336,9 @@ void toParamGet::showMemo(int row)
       ((QLineEdit *)obj)->setText(memo->text());
   }
 }
+
+void toParamGet::resizeEvent(QResizeEvent *e)
+{
+  QDialog::resizeEvent(e);
+  Container->setFixedWidth(View->width()-30);
+}
