@@ -44,8 +44,9 @@
 #include <qdialog.h>
 #include <qpushbutton.h>
 
-class QLineEdit;
+class QComboBox;
 class QGrid;
+class QScrollView;
 
 class toParamGetButton : public QPushButton {
   Q_OBJECT
@@ -69,24 +70,28 @@ class toParamGet : public QDialog, public toHelpContext {
   Q_OBJECT
   /** Default values cache
    */
-  static std::map<QString,std::map<QString,QString> > DefaultCache;
+  static std::map<QString,std::list<QString> > DefaultCache;
   /** Specified values cache
    */
-  static std::map<QString,std::map<QString,QString> > Cache;
+  static std::map<QString,std::list<QString> > Cache;
 
+  QScrollView *View;
   QGrid *Container;
 
-  std::list<QLineEdit *> Value;
+  std::list<QComboBox *> Value;
   toParamGet(QWidget *parent=0,const char *name=0);
+protected:
+  virtual void resizeEvent(QResizeEvent *e);
 public:
   /** Get parameters for specified SQL string.
    * @param conn Connection to get binds for.
    * @param parent Parent widget if dialog is needed.
    * @param str SQL to parse for bindings. Observe that this string can be changed to further
    *            declare the binds.
+   * @param interactive If not interactive simply rewrite the query and pass on the defaults.
    * @return Returns a list of values to feed into the query.
    */
-  static toQList getParam(toConnection &conn,QWidget *parent,QString &str);
+  static toQList getParam(toConnection &conn,QWidget *parent,QString &str,bool interactive=true);
   /** Specify a default value for the cache. This can not overwrite a manually
    * specified value by the user.
    * @param conn Connection to get binds for.
