@@ -1,7 +1,7 @@
 //***************************************************************************
 /*
  * TOra - An Oracle Toolkit for DBA's and developers
- * Copyright (C) 2000-2001,2001 Underscore AB
+ * Copyright (C) 2003 Quest Software, Inc
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,8 +25,8 @@
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries without written consent from Underscore AB. Observe
- *      that this does not disallow linking to the Qt Free Edition.
+ *      these libraries without written consent from Quest Software, Inc.
+ *      Observe that this does not disallow linking to the Qt Free Edition.
  *
  * All trademarks belong to their respective owners.
  *
@@ -35,6 +35,7 @@
 #include "utils.h"
 
 #include "tochangeconnection.h"
+#include "toconf.h"
 #include "toconnection.h"
 #include "tohighlightedtext.h"
 #include "toprofiler.h"
@@ -324,6 +325,27 @@ public:
       else
 	return toResultViewItem::text(col);
     }
+
+    virtual int compare (QListViewItem *i,int col,bool ascending) const
+    {
+      if (col==2||col==3||col==4){
+        toProfilerSource::listItem* item=dynamic_cast<toProfilerSource::listItem*>(i);
+	if(!i)
+	  return QListViewItem::compare(i,col,ascending);
+        else {
+          double val_in=allText(col).toDouble();
+	  double val_out=item->allText(col).toDouble(); 
+	  if (val_in>val_out)
+	    return 1;
+          else if (val_in<val_out)
+	    return -1;
+          else 
+	    return 0;
+	}
+      } else
+	return QListViewItem::compare(i,col,ascending);
+    }
+	
     virtual void paintCell(QPainter *p,const QColorGroup &cg,
 			   int column,int width,int alignment)
     {
@@ -403,27 +425,27 @@ public:
 toProfiler::toProfiler(QWidget *parent,toConnection &connection)
   : toToolWidget(ProfilerTool,"toprofiler.html",parent,connection)
 {
-  QToolBar *toolbar=toAllocBar(this,"Invalid Objects",connection.description());
+  QToolBar *toolbar=toAllocBar(this,tr("PL/SQL Profiler"));
 
   new QToolButton(QPixmap((const char **)refresh_xpm),
-		  "Refresh list",
-		  "Refresh list",
+		  tr("Refresh list"),
+		  tr("Refresh list"),
 		  this,SLOT(refresh()),
 		  toolbar);
 
   toolbar->addSeparator();
 
-  new QLabel("Repeat run ",toolbar);
+  new QLabel(tr("Repeat run")+" ",toolbar,TO_KDE_TOOLBAR_WIDGET);
 
-  Repeat=new QSpinBox(toolbar);
+  Repeat=new QSpinBox(toolbar,TO_KDE_TOOLBAR_WIDGET);
   Repeat->setValue(5);
   Repeat->setMaxValue(1000);
 
   toolbar->addSeparator();
 
-  new QLabel("Comment ",toolbar);
-  Comment=new QLineEdit(toolbar);
-  Comment->setText("Unknown");
+  new QLabel(tr("Comment")+" ",toolbar);
+  Comment=new QLineEdit(toolbar,TO_KDE_TOOLBAR_WIDGET);
+  Comment->setText(tr("Unknown"));
 
   toolbar->addSeparator();
   
@@ -431,27 +453,27 @@ toProfiler::toProfiler(QWidget *parent,toConnection &connection)
   Background=new QToolButton(toolbar);
   Background->setToggleButton(true);
   Background->setIconSet(QIconSet(QPixmap((const char **)background_xpm)));
-  QToolTip::add(Background,"Run profiling in background");
+  QToolTip::add(Background,tr("Run profiling in background"));
 
   toolbar->addSeparator();
 #endif
 
   new QToolButton(QPixmap((const char **)execute_xpm),
-		  "Execute current profiling",
-		  "Execute current profiling",
+		  tr("Execute current profiling"),
+		  tr("Execute current profiling"),
 		  this,SLOT(execute()),
 		  toolbar);
 
-  toolbar->setStretchableWidget(new QLabel(toolbar));
+  toolbar->setStretchableWidget(new QLabel(toolbar,TO_KDE_TOOLBAR_WIDGET));
 
-  new toChangeConnection(toolbar);
+  new toChangeConnection(toolbar,TO_KDE_TOOLBAR_WIDGET);
 
   Tabs=new QTabWidget(this);
   Script=new toWorksheet(Tabs,NULL,connection);
-  Tabs->addTab(Script,"Script");
+  Tabs->addTab(Script,tr("Script"));
 
   Result=new QSplitter(Tabs);
-  Tabs->addTab(Result,"Result");
+  Tabs->addTab(Result,tr("Result"));
 
   QVBox *box=new QVBox(Result);
   Run=new QComboBox(box);
@@ -474,11 +496,10 @@ toProfiler::toProfiler(QWidget *parent,toConnection &connection)
     toQuery query(connection,SQLProfilerDetect);
   } catch(const QString &) {
     int ret=TOMessageBox::warning(this,
-				  "Profiler tables doesn't exist",
-				  "Profiler tables doesn't exist. Should TOra\n"
-				  "try to create them in the current schema.\n"
-				  "Should TOra try to create it?",
-				  "&Yes","&No",0,1);
+				  tr("Profiler tables doesn't exist"),
+				  tr("Profiler tables doesn't exist. Should TOra\n"
+				     "try to create them in the current schema?"),
+				  tr("&Yes"),tr("&No"),QString::null,0,1);
     if (ret==0) {
       try {
 	connection.execute(SQLProfilerRuns);
@@ -502,7 +523,7 @@ toProfiler::toProfiler(QWidget *parent,toConnection &connection)
 void toProfiler::refresh(void)
 {
   Run->clear();
-  Run->insertItem("Select run");
+  Run->insertItem(tr("Select run"));
   try {
     toQuery query(connection(),SQLListRuns);
     int id=1;
@@ -512,9 +533,9 @@ void toProfiler::refresh(void)
       QString comment=query.readValueNull();
       double total=query.readValueNull().toDouble()/1E9;
       if (!owner.isEmpty())
-	owner="("+owner+")";
-      QString timstr=" ["+FormatTime(total)+"]";
-      Run->insertItem(runid+owner+": "+comment+timstr);
+	owner=QString::fromLatin1("(")+owner+QString::fromLatin1(")");
+      QString timstr=QString::fromLatin1(" [")+FormatTime(total)+QString::fromLatin1("]");
+      Run->insertItem(runid+owner+QString::fromLatin1(": ")+comment+timstr);
       if (runid.toInt()==CurrentRun) {
 	Run->setCurrentItem(id);
         changeRun();
@@ -531,29 +552,29 @@ void toProfiler::execute(void)
     exc=toSQL::string(SQLStartProfiler,connection());
     for(int i=0;i<Repeat->value();i++) {
       exc+=Script->editor()->text();
-      exc+="\n";
+      exc+=QString::fromLatin1("\n");
     }
     exc+=toSQL::string(SQLStopProfiler,connection());
 
     toQuery query(connection(),
 		  exc,
 		  Comment->text(),
-		  QString::number(Repeat->value())+" runs");
+		  tr("%1 runs").arg(Repeat->value()));
     CurrentRun=query.readValue().toInt();
     if (CurrentRun>0) {
       Tabs->showPage(Result);
       refresh();
     } else
-      toStatusMessage("Something went wrong collecting statistics");
+      toStatusMessage(tr("Something went wrong collecting statistics"));
   } TOCATCH
 }
 
 void toProfiler::changeRun(void)
 {
   QString t=Run->currentText();
-  int pos=t.find("(");
+  int pos=t.find(QString::fromLatin1("("));
   if (pos<0)
-    pos=t.find(":");
+    pos=t.find(QString::fromLatin1(":"));
   if (pos>=0)
     CurrentRun=t.mid(0,pos).toInt();
   QString run=QString::number(CurrentRun);
@@ -582,6 +603,8 @@ void toProfiler::changeObject(void)
     toPush(par,toQValue(item->allText(5)));
     toPush(par,toQValue(item->allText(6)));
     Lines->clearTotals();
-    Lines->query(toSQL::string(SQLListSource,connection()),par);
+    try {
+      Lines->query(toSQL::string(SQLListSource,connection()),par);
+    } TOCATCH
   }
 }
