@@ -170,7 +170,7 @@ toResultContentEditor::contentItem::contentItem(QTable *table,const QString &tex
 
 QString toResultContentEditor::contentItem::key(void) const
 {
-  static QRegExp number(QString::fromLatin1("^\\d*\\.?\\d+E?-?\\d*.?.?$"));
+  static QRegExp number(QString::fromLatin1("^-?\\d*\\.?\\d+E?-?\\d*.?.?$"));
 
   QString txt=text();
   if (number.match(txt)>=0) {
@@ -279,6 +279,7 @@ toResultContentEditor::toResultContentEditor(QWidget *parent,const char *name)
 		 true,true,true)
 {
   CurrentEditor=NULL;
+  BinaryColumns=0;
   SearchStart=SearchEnd=0;
   NoUseReturning=false;
   AllFilter=false;
@@ -298,6 +299,15 @@ toResultContentEditor::toResultContentEditor(QWidget *parent,const char *name)
   Menu=new QPopupMenu(this);
   Menu->insertItem(tr("&Display in editor..."),TORESULT_MEMO);
   Menu->insertSeparator();
+  Menu->insertItem(QPixmap((const char **)addrecord_xpm),tr("New record"),this,SLOT(addRecord()));
+  Menu->insertItem(QPixmap((const char **)duplicaterecord_xpm),tr("Copy record"),this,SLOT(duplicateRecord()));
+  Menu->insertItem(QPixmap((const char **)saverecord_xpm),tr("Save changes"),this,SLOT(saveUnsaved()));
+  Menu->insertItem(QPixmap((const char **)canceledit_xpm),tr("Discard changes"),this,SLOT(cancelEdit()));
+  Menu->insertItem(QPixmap((const char **)trash_xpm),tr("Delete record"),this,SLOT(deleteCurrent()));
+  Menu->insertSeparator();
+  Menu->insertItem(QPixmap((const char **)filter_xpm),tr("Define filter"),parentWidget(),SLOT(changeFilter()));
+  Menu->insertItem(QPixmap((const char **)nofilter_xpm),tr("Remove all filters"),parentWidget(),SLOT(removeFilter()));
+  Menu->insertSeparator();
   Menu->insertItem(tr("&Copy field"),TORESULT_COPY_FIELD);
   Menu->insertItem(tr("&Paste field"),TORESULT_PASTE);
   Menu->insertSeparator();
@@ -308,7 +318,6 @@ toResultContentEditor::toResultContentEditor(QWidget *parent,const char *name)
   Menu->insertItem(tr("&Delete record"),TORESULT_DELETE);
   Menu->insertSeparator();
   Menu->insertItem(tr("Select all"),TORESULT_SELECT_ALL);
-  Menu->setAccel(CTRL+Key_A,TORESULT_SELECT_ALL);
   Menu->insertSeparator();
   Menu->insertItem(tr("Export to file..."),TORESULT_EXPORT);
   Menu->insertItem(tr("Read all"),TORESULT_READ_ALL);
@@ -327,7 +336,9 @@ toResultContentEditor::toResultContentEditor(QWidget *parent,const char *name)
 
 toResultContentEditor::~toResultContentEditor()
 {
+  saveUnsaved();
   delete Query;
+  delete BinaryColumns;
 }
 
 void toResultContentEditor::wrongUsage(void)
@@ -429,6 +440,12 @@ void toResultContentEditor::poll(void)
       bool first=false;
       if (numRows()==0) {
 	Description=Query->describe();
+
+	delete BinaryColumns;
+	BinaryColumns=new bool[Description.size()];
+	for(unsigned int j=0;j<Description.size();j++)
+	  BinaryColumns[j]=false;
+
 	setNumCols(Description.size());
 
 	QHeader *head=horizontalHeader();
@@ -450,8 +467,11 @@ void toResultContentEditor::poll(void)
 	    toQValue val=Query->readValueNull();
 	    if (val.isDouble())
 	      data.insert(data.end(),QString::number(val.toDouble()));
-	    else
+	    else {
+	      if (val.isBinary())
+		BinaryColumns[k]=true;
 	      data.insert(data.end(),val);
+	    }
 	    dataSize++;
 	  } else
 	    Query->readValueNull();
@@ -754,8 +774,8 @@ void toResultContentEditor::deleteCurrent()
       bool oracle=(connection().provider()=="Oracle");
       {
         for(int i=0;i<numCols();i++) {
-	  if (!oracle||(!(*di).Datatype.startsWith(("LONG"))&&
-			!(*di).Datatype.contains(("LOB")))) {
+	  if (!oracle||(!(*di).Datatype.upper().startsWith(("LONG"))&&
+			!(*di).Datatype.upper().contains(("LOB")))) {
 	    if (where)
 	      sql+=(" AND ");
 	    else
@@ -766,7 +786,10 @@ void toResultContentEditor::deleteCurrent()
 	    else {
 	      sql+=("= :c");
 	      sql+=QString::number(i);
-	      sql+=("<char[4000]>");
+	      if (BinaryColumns[i]) {
+		sql+=("<raw_long>");
+	      } else
+		sql+=("<char[4000]>");
 	    }
 	  }
 	  di++;
@@ -780,9 +803,13 @@ void toResultContentEditor::deleteCurrent()
       di=Description.begin();
       for(int i=0;i<numCols();i++) {
 	QString str=text(currentRow(),i);
-	if (!str.isNull()&&(!oracle||(!(*di).Datatype.startsWith(("LONG"))&&
-				      !(*di).Datatype.contains(("LOB")))))
-	  toPush(args,toQValue(str));
+	if (!str.isNull()&&(!oracle||(!(*di).Datatype.upper().startsWith(("LONG"))&&
+				      !(*di).Datatype.upper().contains(("LOB"))))) {
+	  if (BinaryColumns[i])
+	    toPush(args,toQValue::createFromHex(str));
+	  else
+	    toPush(args,toQValue(str));
+	}
 	di++;
       }
       conn.execute(sql,args);
@@ -840,25 +867,39 @@ void toResultContentEditor::saveUnsaved(void)
 	sql+=" (";
 	int num=0;
 	QHeader *head=horizontalHeader();
-	for (int i=0;i<numCols();i++) {
-	  if (!text(CurrentRow,i).isNull()) {
-	    if (num>0)
-	      sql+=",";
-	    sql+=conn.quote(head->label(i));
-	    num++;
+	{
+	  for (int i=0;i<numCols();i++) {
+	    if (!text(CurrentRow,i).isNull()) {
+	      if (num>0)
+		sql+=",";
+	      sql+=conn.quote(head->label(i));
+	      num++;
+	    }
 	  }
 	}
 	sql+=") VALUES (";
 	num=0;
-	for (int i=0;i<numCols();i++) {
+	toQDescList::iterator di=Description.begin();
+	for (int i=0;i<numCols()&&di!=Description.end();i++) {
 	  if (!text(CurrentRow,i).isNull()) {
 	    if (num>0)
 	      sql+=(",");
 	    sql+=(":f");
 	    sql+=QString::number(num+1);
-	    sql+=("<char[4000],in>");
+	    if (BinaryColumns[i]) {
+	      if ((*di).Datatype.upper().contains("LOB"))
+		sql+=("<blob>");
+	      else
+		sql+=("<raw_long,in>");
+	    } else {
+	      if ((*di).Datatype.upper().contains("LOB"))
+		sql+=("<clob>");
+	      else
+		sql+=("<char[4000],in>");
+	    }
 	    num++;
 	  }
+	  di++;
 	}
 	sql+=(")");
 	if(oracle&&!NoUseReturning) 
@@ -868,8 +909,12 @@ void toResultContentEditor::saveUnsaved(void)
 	  toQList args;
 	  for (int i=0;i<numCols();i++) {
 	    QString str=text(CurrentRow,i);
-	    if (!str.isNull())
-	      toPush(args,toQValue(str));
+	    if (!str.isNull()) {
+	      if (BinaryColumns[i])
+		toPush(args,toQValue::createFromHex(str));
+	      else
+		toPush(args,toQValue(str));
+	    }
 	  }
 	  toQuery q(conn,sql,args);
 	  if(oracle&&!NoUseReturning)
@@ -892,7 +937,8 @@ void toResultContentEditor::saveUnsaved(void)
 	QHeader *head=horizontalHeader();
 	std::list<QString>::iterator k=OrigValues.begin();
 	bool first=false;
-	for(int i=0;i<numCols();i++,k++) {
+	toQDescList::iterator di=Description.begin();
+	for(int i=0;i<numCols()&&di!=Description.end();i++,k++) {
 	  QString fld=text(CurrentRow,i);
 	  if (*k!=fld) {
 	    if (!first)
@@ -905,30 +951,42 @@ void toResultContentEditor::saveUnsaved(void)
 	    else {
 	      sql+=("= :f");
 	      sql+=QString::number(i);
-	      sql+=("<char[4000],in>");
+	      if (BinaryColumns[i]) {
+		if ((*di).Datatype.upper().contains("LOB"))
+		  sql+=("<blob>");
+		else
+		  sql+=("<raw_long,in>");
+	      } else {
+		if ((*di).Datatype.upper().contains("LOB"))
+		  sql+=("<clob>");
+		else
+		  sql+=("<char[4000],in>");
+	      }
 	    }
 	  }
+	  di++;
 	}
 	if (first) {
-	  sql+=(" WHERE ");
+	  sql+=(" WHERE (");
 	  int col=0;
 	  bool where=false;
 	  toQDescList::iterator di=Description.begin();
 	  for(std::list<QString>::iterator j=OrigValues.begin();j!=OrigValues.end();j++,col++) {
-	    if (!oracle||(!(*di).Datatype.startsWith(("LONG"))&&
-			  !(*di).Datatype.contains(("LOB")))) {
+	    if (!oracle||(!(*di).Datatype.upper().startsWith(("LONG"))&&
+			  !(*di).Datatype.upper().contains(("LOB")))) {
 	      if (where)
-		sql+=(" AND ");
+		sql+=(" AND (");
 	      else
 		where=true;
 	      sql+=conn.quote((*di).Name);
-	      if ((*j).isNull())
-		sql+=(" IS NULL");
-	      else {
-		sql+=("= :c");
-		sql+=QString::number(col);
-		sql+=("<char[4000],in>");
-	      }
+	      if ((*j).isEmpty())
+		sql+=" IS NULL OR "+conn.quote((*di).Name);
+	      sql+=("= :c");
+	      sql+=QString::number(col);
+	      if (BinaryColumns[col])
+		sql+=("<raw_long,in>)");
+	      else
+		sql+=("<char[4000],in>)");
 	    }
 	    di++;
 	  }
@@ -944,16 +1002,27 @@ void toResultContentEditor::saveUnsaved(void)
 	    std::list<QString>::iterator k=OrigValues.begin();
 	    for (int i=0;i<numCols();i++,k++) {
 	      QString str=text(CurrentRow,i);
-	      if (str!=*k&&!str.isNull())
-		toPush(args,toQValue(str));
+	      if (str!=*k&&!str.isNull()) {
+		if (BinaryColumns[i])
+		  toPush(args,toQValue::createFromHex(str));
+		else
+		  toPush(args,toQValue(str));
+	      }
 	    }
 
+	    col=0;
 	    toQDescList::iterator di=Description.begin();
 	    for(std::list<QString>::iterator j=OrigValues.begin();j!=OrigValues.end();j++,col++) {
 	      QString str=(*j);
-	      if (!str.isNull()&&(!oracle||(!(*di).Datatype.startsWith(("LONG"))&&
-					    !(*di).Datatype.contains(("LOB")))))
-		toPush(args,toQValue(str));
+	      if (!oracle||(!(*di).Datatype.upper().startsWith(("LONG"))&&
+			    !(*di).Datatype.upper().contains(("LOB")))) {
+		if (str.isNull())
+		  toPush(args,toQValue(QString("")));
+		else if (BinaryColumns[col])
+		  toPush(args,toQValue::createFromHex(str));
+		else
+		  toPush(args,toQValue(str));
+	      }
 	      di++;
 	    }
 	    toQuery q(conn,sql,args);
@@ -972,6 +1041,8 @@ void toResultContentEditor::saveUnsaved(void)
 	  }
 	}
       }
+
+      emit changesSaved();
     } TOCATCH
     OrigValues.clear();
     if(oracle) {
@@ -1301,6 +1372,7 @@ toResultContent::toResultContent(QWidget *parent,const char *name)
   toolbar->setStretchableWidget(new QLabel(toolbar,TO_KDE_TOOLBAR_WIDGET));
   connect(toMainWidget(),SIGNAL(willCommit(toConnection &,bool)),
 	  this,SLOT(saveUnsaved(toConnection &,bool)));
+  connect(Editor,SIGNAL(changesSaved()),this,SIGNAL(changesSaved()));
 }
 
 void toResultContent::changeFilter(void)
