@@ -56,6 +56,19 @@
 #include "icons/scansource.xpm"
 #include "icons/tocurrent.xpm"
 #include "icons/trash.xpm"
+#include "icons/commit.xpm"
+
+static toSQL SQLParamsMySQL("toResultParam:ListParam",
+			    "TOAD 1,2 show variables",
+			    "List parameters available in the session",
+			    "4.0",
+			    "MySQL");
+
+static toSQL SQLParamsGlobal("toResultParam:ListGlobal",
+			     "TOAD 1,2 show global variables",
+			     "List parameters available in the database",
+			     "4.0",
+			     "MySQL");
 
 static toSQL SQLParams("toResultParam:ListParam",
 		       "select name \"Parameter\",value \"Value\",' ' \"Changed\",\n"
@@ -63,7 +76,7 @@ static toSQL SQLParams("toResultParam:ListParam",
 		       "       type \" Type\",isdefault \" Default\",\n"
 		       "       isses_modifiable \" Sesmod\",issys_modifiable \" Sysmod\"\n"
 		       "  from v$parameter order by name",
-		       "List parameters available in the database");
+		       "");
 
 static toSQL SQLHiddenParams("toResultParam:ListHidden",
 			     "SELECT KSPPINM \"Parameter\",\n"
@@ -82,38 +95,55 @@ static toSQL SQLHiddenParams("toResultParam:ListHidden",
 
 bool toResultParam::canHandle(toConnection &conn)
 {
-  return toIsOracle(conn);
+  return toIsOracle(conn)||toIsMySQL(conn);
 }
 
 toResultParam::toResultParam(QWidget *parent,const char *name)
   : QVBox(parent,name)
 {
   QToolBar *toolbar=toAllocBar(this,tr("Parameter editor"));
-  Hidden=new QToolButton(toolbar);
-  Hidden->setToggleButton(true);
-  Hidden->setIconSet(QIconSet(QPixmap((const char **)scansource_xpm)));
-  connect(Hidden,SIGNAL(toggled(bool)),this,SLOT(showHidden(bool)));
-  QToolTip::add(Hidden,tr("Display hidden parameters. This will only word if you are logged in as the sys user."));
+  Toggle=new QToolButton(toolbar);
+  Toggle->setToggleButton(true);
+  if (toIsOracle(connection())) {
+    Toggle->setIconSet(QIconSet(QPixmap((const char **)scansource_xpm)));
+    connect(Toggle,SIGNAL(toggled(bool)),this,SLOT(showHidden(bool)));
+    QToolTip::add(Toggle,tr("Display hidden parameters. This will only word if you are logged in as the sys user."));
+  } else {
+    QIconSet iconset(QPixmap((const char **)tocurrent_xpm));
+    iconset.setPixmap(QPixmap((const char **)database_xpm),QIconSet::Automatic,QIconSet::Normal,QIconSet::On);
+    Toggle->setIconSet(iconset);
+    connect(Toggle,SIGNAL(toggled(bool)),this,SLOT(showGlobal(bool)));
+    QToolTip::add(Toggle,tr("Switch between global and session variables to show."));
+  }
   toolbar->addSeparator();
 
   new QToolButton(QPixmap((const char **)filesave_xpm),
-		  tr("Generate pfile"),
-		  tr("Generate pfile"),
+		  tr("Generate configuration file"),
+		  tr("Generate configuration file"),
 		  this,SLOT(generateFile()),toolbar);
   toolbar->addSeparator();
-  new QToolButton(QPixmap((const char **)database_xpm),
-		  tr("Apply changes to system"),
-		  tr("Apply changes to system"),
-		  this,SLOT(applySystem()),toolbar);
-  new QToolButton(QPixmap((const char **)tocurrent_xpm),
-		  tr("Apply changes to session"),
-		  tr("Apply changes to session"),
-		  this,SLOT(applySession()),toolbar);
-  toolbar->addSeparator();
-  new QToolButton(QPixmap((const char **)trash_xpm),
-		  tr("Drop current changes"),
-		  tr("Drop current changes"),
-		  this,SLOT(dropChanges()),toolbar);
+  if (toIsOracle(connection())) {
+    new QToolButton(QPixmap((const char **)database_xpm),
+		    tr("Apply changes to system"),
+		    tr("Apply changes to system"),
+		    this,SLOT(applySystem()),toolbar);
+    new QToolButton(QPixmap((const char **)tocurrent_xpm),
+		    tr("Apply changes to session"),
+		    tr("Apply changes to session"),
+		    this,SLOT(applySession()),toolbar);
+  } else {
+    new QToolButton(QPixmap((const char **)commit_xpm),
+		    tr("Apply changes"),
+		    tr("Apply changes"),
+		    this,SLOT(applyChanges()),toolbar);
+  }
+  if (toIsOracle(connection())) {
+    toolbar->addSeparator();
+    new QToolButton(QPixmap((const char **)trash_xpm),
+		    tr("Drop current changes"),
+		    tr("Drop current changes"),
+		    this,SLOT(dropChanges()),toolbar);
+  }
   toolbar->setStretchableWidget(new QLabel(toolbar,TO_KDE_TOOLBAR_WIDGET));
 
   Params=new toResultLong(false,false,toQuery::Background,this);
@@ -124,7 +154,7 @@ toResultParam::toResultParam(QWidget *parent,const char *name)
   connect(Params,SIGNAL(done()),this,SLOT(done()));
   Value=new QLineEdit(this);
   Value->setEnabled(false);
-  LastItem=-1;
+  refresh();
 }
 
 void toResultParam::showHidden(bool hid)
@@ -136,10 +166,19 @@ void toResultParam::showHidden(bool hid)
   refresh();
 }
 
+void toResultParam::showGlobal(bool glb)
+{
+  if (glb)
+    Params->setSQL(SQLParamsGlobal);
+  else
+    Params->setSQL(SQLParams);
+  refresh();
+}
+
 void toResultParam::query(const QString &,const toQList &)
 {
   saveChange();
-  LastItem=-1;
+  LastItem=QString::null;
 
   Params->refresh();
 }
@@ -153,7 +192,7 @@ void toResultParam::dropChanges(void)
 void toResultParam::done()
 {
   for(QListViewItem *item=Params->firstChild();item;item=item->nextSibling()) {
-    std::map<int,QString>::iterator i=NewValues.find(item->text(4).toInt());
+    std::map<QString,QString>::iterator i=NewValues.find(item->text(0));
     if (i!=NewValues.end()) {
       item->setText(1,(*i).second);
       item->setText(6,QString::fromLatin1("FALSE"));
@@ -164,11 +203,11 @@ void toResultParam::done()
 
 void toResultParam::saveChange()
 {
-  if(LastItem>=0&&LastValue!=Value->text()) {
+  if(!LastItem.isEmpty()&&LastValue!=Value->text()) {
     NewValues[LastItem]=Value->text();
     LastValue=Value->text();
     for(QListViewItem *item=Params->firstChild();item;item=item->nextSibling()) {
-      if (item->text(4).toInt()==LastItem) {
+      if (item->text(0)==LastItem) {
 	item->setText(1,LastValue);
 	item->setText(6,QString::fromLatin1("FALSE"));
 	item->setText(2,tr("Changed"));
@@ -184,23 +223,27 @@ void toResultParam::generateFile(void)
   QString str=tr("# Generated by TOra version %1\n\n").arg(QString::fromLatin1(TOVERSION));
   QRegExp comma(QString::fromLatin1("\\s*,\\s+"));
   for(QListViewItem *item=Params->firstChild();item;item=item->nextSibling()) {
-    if (item->text(6)==QString::fromLatin1("FALSE")) {
-      str+=item->text(0);
-      str+=QString::fromLatin1(" = ");
-      if(item->text(5)==QString::fromLatin1("2")) {
-	QStringList lst=QStringList::split(comma,item->text(1));
-	if (lst.count()>1)
-	  str+=QString::fromLatin1("( ");
-	for(unsigned int i=0;i<lst.count();i++) {
-	  if (i>0)
-	    str+=QString::fromLatin1(", ");
-	  str+=QString::fromLatin1("\"")+lst[i]+QString::fromLatin1("\"");
-	}
-	if (lst.count()>1)
-	  str+=QString::fromLatin1(" )");
-      } else
-	str+=item->text(1);
-      str+=QString::fromLatin1("\n");
+    if (toIsOracle(connection())) {
+      if (item->text(6)==QString::fromLatin1("FALSE")) {
+	str+=item->text(0);
+	str+=QString::fromLatin1(" = ");
+	if(item->text(5)==QString::fromLatin1("2")) {
+	  QStringList lst=QStringList::split(comma,item->text(1));
+	  if (lst.count()>1)
+	    str+=QString::fromLatin1("( ");
+	  for(unsigned int i=0;i<lst.count();i++) {
+	    if (i>0)
+	      str+=QString::fromLatin1(", ");
+	    str+=QString::fromLatin1("\"")+lst[i]+QString::fromLatin1("\"");
+	  }
+	  if (lst.count()>1)
+	    str+=QString::fromLatin1(" )");
+	} else
+	  str+=item->text(1);
+	str+=QString::fromLatin1("\n");
+      }
+    } else {
+      str+=item->text(0)+" = '"+item->text(1)+"'\n";
     }
   }
   connect(new toMemoEditor(this,str,0,0),SIGNAL(changeData(int,int,const QString &)),
@@ -226,7 +269,7 @@ void toResultParam::applySession(void)
 	    } else
 	      str+=item->text(1);
 	    conn.allExecute(str);
-	    std::map<int,QString>::iterator i=NewValues.find(item->text(4).toInt());
+	    std::map<QString,QString>::iterator i=NewValues.find(item->text(0));
 	    if (i!=NewValues.end())
 	      NewValues.erase(i);
 	  }
@@ -256,7 +299,7 @@ void toResultParam::applySystem(void)
 	    } else
 	      str+=item->text(1);
 	    conn.execute(str);
-	    std::map<int,QString>::iterator i=NewValues.find(item->text(4).toInt());
+	    std::map<QString,QString>::iterator i=NewValues.find(item->text(0));
 	    if (i!=NewValues.end())
 	      NewValues.erase(i);
 	  }
@@ -267,25 +310,56 @@ void toResultParam::applySystem(void)
   refresh();
 }
 
+// Only used by MySQL
+
+void toResultParam::applyChanges(void)
+{
+  try {
+    saveChange();
+    toConnection &conn=connection();
+    for(QListViewItem *item=Params->firstChild();item;item=item->nextSibling()) {
+      if (item->text(2)==tr("Changed")) {
+	try {
+	  QString str="SET ";
+	  if (!Toggle->isOn())
+	    str+="GLOBAL ";
+	  else
+	    str+="SESSION ";
+	  str+=item->text(0);
+	  str+=" = ";
+	  str+=QString::fromLatin1("'");
+	  str+=item->text(1);
+	  str+=QString::fromLatin1("'");
+	  conn.execute(str);
+	  std::map<QString,QString>::iterator i=NewValues.find(item->text(0));
+	  if (i!=NewValues.end())
+	    NewValues.erase(i);
+	} TOCATCH
+      }
+    }
+  } TOCATCH
+  refresh();
+}
+
 void toResultParam::changeItem(void)
 {
   saveChange();
 
   QListViewItem *item=Params->selectedItem();
   if (item) {
-    LastItem=item->text(4).toInt();
+    LastItem=item->text(0);
     LastValue=item->text(1);
     Value->setText(LastValue);
     Value->setEnabled(true);
   } else {
-    LastItem=-1;
+    LastItem=QString::null;
     Value->setEnabled(false);
   }
 }
 
 void toResultParam::changedData(int,int,const QString &data)
 {
-  QString file=toSaveFilename(QString::null,QString::fromLatin1("*.pfile"),this);
+  QString file=toSaveFilename(QString::null,toIsOracle(connection())?"*.pfile":"*.conf",this);
   if (!file.isEmpty())
     toWriteFile(file,data);
 }
