@@ -41,6 +41,8 @@
 
 #include <list>
 
+#include <qregexp.h>
+
 class toNoBlockQuery;
 class toSQL;
 
@@ -57,6 +59,9 @@ class toResultPie : public toPieChart, public toResult {
   toBackground Poll;
   int Columns;
   bool Started;
+  bool LabelFirst;
+  QRegExp Filter;
+  QRegExp ValueFilter;
 public:
   /** Create widget.
    * @param parent Parent of list.
@@ -77,6 +82,29 @@ public:
    */
   void start();
 
+  /** Indicate that the first column should be the label.
+   */
+  void setLabelFirst(bool first)
+  { LabelFirst=first; }
+  /** Check label first status.
+   */
+  bool labelFirst(void)
+  { return LabelFirst; }
+  /** Set a filter on which columns to add based on label.
+   * @param filter A regexp which the label must match.
+   * @param valueFilter A regexp which the value must match.
+   */
+  void setFilter(const QRegExp &filter,const QRegExp &valueFilter)
+  { Filter=filter; ValueFilter=valueFilter; }
+  /** Get the current filter.
+   */
+  const QRegExp &filter(void)
+  { return Filter; }
+  /** Get the current value filter.
+   */
+  const QRegExp &valueFilter(void)
+  { return ValueFilter; }
+
   // Why are these needed?
 #if 1
   /** Set the SQL statement of this list
