@@ -73,6 +73,7 @@
 #include "toresultview.moc"
 
 static int MaxColDisp;
+static bool Gridlines;
 
 void toResultViewMLine::setText (int col,const QString &text)
 {
@@ -108,6 +109,11 @@ void toResultViewMLine::paintCell(QPainter *pnt,const QColorGroup & cg,
   toResultViewItem::paintCell(pnt,cg,column,
 			      max(QListViewItem::width(pnt->fontMetrics(),listView(),column),width),
 			      alignment);
+  if (Gridlines) {
+    pnt->setPen(gray);
+    pnt->drawLine(width-1,0,width-1,height());
+    pnt->drawLine(0,height()-1,width-1,height()-1);
+  }
 }
 
 static int TextWidth(const QFontMetrics &fm,const QString &str)
@@ -127,12 +133,14 @@ static int TextWidth(const QFontMetrics &fm,const QString &str)
 
 int toResultViewMLine::realWidth(const QFontMetrics &fm, const QListView *top, int column,const QString &txt) const
 {
-  if (!MaxColDisp)
+  if (!MaxColDisp) {
     MaxColDisp=toTool::globalConfig(CONF_MAX_COL_DISP,DEFAULT_MAX_COL_DISP).toInt();
+    Gridlines=!toTool::globalConfig(CONF_DISPLAY_GRIDLINES,DEFAULT_DISPLAY_GRIDLINES).isEmpty();
+  }
   QString t=text(column);
   if (t.isNull())
     t=txt;
-  return min(TextWidth(fm,t),MaxColDisp)+top->itemMargin()*2+2;
+  return min(TextWidth(fm,t),MaxColDisp)+top->itemMargin()*2-fm.minLeftBearing()-fm.minRightBearing()+1;
 }
 
 QString toResultViewItem::firstText(int col) const
@@ -157,13 +165,15 @@ QString toResultViewItem::text(int col) const
 
 int toResultViewItem::realWidth(const QFontMetrics &fm, const QListView *top, int column,const QString &txt) const
 {
-  if (!MaxColDisp)
+  if (!MaxColDisp) {
     MaxColDisp=toTool::globalConfig(CONF_MAX_COL_DISP,DEFAULT_MAX_COL_DISP).toInt();
+    Gridlines=!toTool::globalConfig(CONF_DISPLAY_GRIDLINES,DEFAULT_DISPLAY_GRIDLINES).isEmpty();
+  }
   QString t=text(column);
   if (t.isNull())
     t=txt;
   QRect bounds=fm.boundingRect(t);
-  return min(bounds.width(),MaxColDisp)+top->itemMargin()*2+2;
+  return min(bounds.width(),MaxColDisp)+top->itemMargin()*2-fm.minLeftBearing()-fm.minRightBearing()+1;
 }
 
 void toResultViewItem::paintCell(QPainter * p,const QColorGroup & cg,int column,int width,int align)
@@ -172,6 +182,11 @@ void toResultViewItem::paintCell(QPainter * p,const QColorGroup & cg,int column,
   toResultView *view=dynamic_cast<toResultView *>(listView());
   if (view&&(itemBelow()==NULL||itemBelow()->itemBelow()==NULL))
     view->addItem();
+  if (Gridlines) {
+    p->setPen(gray);
+    p->drawLine(width-1,0,width-1,height());
+    p->drawLine(0,height()-1,width-1,height()-1);
+  }
 }
 
 #define ALLOC_SIZE 10
@@ -195,7 +210,7 @@ void toResultViewItem::setText (int col,const QString &txt)
       ColumnCount=ns;
     }
 
-    static QRegExp number(QString::fromLatin1("^\\d*\\.?\\d+E?-?\\d*.?.?$"));
+    static QRegExp number(QString::fromLatin1("^-?\\d*\\.?\\d+E?-?\\d*.?.?$"));
 
     ColumnData[col].Data=txt;
 
@@ -350,12 +365,14 @@ void toResultViewMLCheck::paintCell (QPainter *pnt,const QColorGroup & cg,
 
 int toResultViewMLCheck::realWidth(const QFontMetrics &fm, const QListView *top, int column,const QString &txt) const
 {
-  if (!MaxColDisp)
+  if (!MaxColDisp) {
     MaxColDisp=toTool::globalConfig(CONF_MAX_COL_DISP,DEFAULT_MAX_COL_DISP).toInt();
+    Gridlines=!toTool::globalConfig(CONF_DISPLAY_GRIDLINES,DEFAULT_DISPLAY_GRIDLINES).isEmpty();
+  }
   QString t=text(column);
   if (t.isNull())
     t=txt;
-  int wx=top->itemMargin()*2+2;
+  int wx=top->itemMargin()*2-fm.minLeftBearing()-fm.minRightBearing()+1;
   if (column==0)
 #if QT_VERSION >= 0x030100
     wx+=top->style().pixelMetric(QStyle::PM_CheckListButtonSize)+4+top->itemMargin();
@@ -367,13 +384,15 @@ int toResultViewMLCheck::realWidth(const QFontMetrics &fm, const QListView *top,
 
 int toResultViewCheck::realWidth(const QFontMetrics &fm, const QListView *top, int column,const QString &txt) const
 {
-  if (!MaxColDisp)
+  if (!MaxColDisp) {
     MaxColDisp=toTool::globalConfig(CONF_MAX_COL_DISP,DEFAULT_MAX_COL_DISP).toInt();
+    Gridlines=!toTool::globalConfig(CONF_DISPLAY_GRIDLINES,DEFAULT_DISPLAY_GRIDLINES).isEmpty();
+  }
   QString t=text(column);
   if (t.isNull())
     t=txt;
   QRect bounds=fm.boundingRect(t);
-  int wx=top->itemMargin()*2+2;
+  int wx=top->itemMargin()*2-fm.minLeftBearing()-fm.minRightBearing()+1;
   if (column==0)
 #if QT_VERSION >= 0x030100
     wx+=top->style().pixelMetric(QStyle::PM_CheckListButtonSize)+4+top->itemMargin();
@@ -441,7 +460,8 @@ public:
 	key=chkItem->tooltip(col);
       else
 	key=text;
-      int textWidth=TextWidth(List->fontMetrics(),text)+List->itemMargin()*2+2;
+      int textWidth=TextWidth(List->fontMetrics(),text)+List->itemMargin()*2-
+	List->fontMetrics().minLeftBearing()-List->fontMetrics().minRightBearing()+1;
       if (key!=text||
 	  width<textWidth) {
 	QRect itemRect=List->itemRect(item);
@@ -453,12 +473,12 @@ public:
   }
 };
 
-toListView::toListView(QWidget *parent,const char *name)
-  : QListView(parent,name),
+toListView::toListView(QWidget *parent,const char *name,WFlags f)
+  : QListView(parent,name,f),
     toEditWidget(false,true,true,
 		 false,false,
 		 false,false,false,
-		 true,false,false)
+		 true,true,false)
 {
   FirstSearch=false;
   setTreeStepSize(15);
@@ -511,6 +531,8 @@ void toListView::contentsMouseDoubleClickEvent (QMouseEvent *e)
     } catch(...) {
     }
   }
+
+  QListView::contentsMouseDoubleClickEvent(e);
 }
 
 void toListView::contentsMouseMoveEvent (QMouseEvent *e)
@@ -739,7 +761,6 @@ void toListView::displayMenu(QListViewItem *item,const QPoint &p,int col)
       if (selectionMode()==Multi||selectionMode()==Extended) {
 	Menu->insertSeparator();
 	Menu->insertItem(tr("Select all"),TORESULT_SELECT_ALL);
-	Menu->setAccel(CTRL+Key_A,TORESULT_SELECT_ALL);
       }
       Menu->insertSeparator();
       Menu->insertItem(tr("Export to file..."),TORESULT_EXPORT);
@@ -749,6 +770,7 @@ void toListView::displayMenu(QListViewItem *item,const QPoint &p,int col)
       }
       connect(Menu,SIGNAL(activated(int)),this,SLOT(menuCallback(int)));
       addMenues(Menu);
+      emit displayMenu(Menu);
     }
     MenuItem=item;
     MenuColumn=col;
@@ -1096,7 +1118,11 @@ QString toListView::exportAsText(bool includeHeader,bool onlySelection,int type,
 	output=output.left(output.length()-1);
       else if (type==3&&includeHeader)
 	output+=QString::fromLatin1("</TR>");
-      output+=QString::fromLatin1("\n");
+#ifdef WIN32
+      output+="\r\n";
+#else
+      output+="\n";
+#endif
       if (type==0) {
 	for (int k=0;k<columns();k++) {
 	  for (int l=0;l<sizes[k];l++)
@@ -1104,7 +1130,11 @@ QString toListView::exportAsText(bool includeHeader,bool onlySelection,int type,
 	  if (k!=columns()-1)
 	    output+=QString::fromLatin1(" ");
 	}
-	output+=QString::fromLatin1("\n");
+#ifdef WIN32
+        output+="\r\n";
+#else
+        output+="\n";
+#endif
       }
     }
 
@@ -1176,7 +1206,11 @@ QString toListView::exportAsText(bool includeHeader,bool onlySelection,int type,
 	  line=line.left(line.length()-separator.length());
 	else 
 	  line=line.left(line.length()-1);
-	line+=QString::fromLatin1("\n");
+#ifdef WIN32
+        line+="\r\n";
+#else
+        line+="\n";
+#endif
 	output+=line;
       }
 
@@ -1330,14 +1364,14 @@ void toResultView::setup(bool readable,bool dispCol)
   SortAscending=true;
 }
 
-toResultView::toResultView(bool readable,bool dispCol,QWidget *parent,const char *name)
-  : toListView(parent,name)
+toResultView::toResultView(bool readable,bool dispCol,QWidget *parent,const char *name,WFlags f)
+  : toListView(parent,name,f)
 {
   setup(readable,dispCol);
 }
 
-toResultView::toResultView(QWidget *parent,const char *name)
-  : toListView(parent,name)
+toResultView::toResultView(QWidget *parent,const char *name,WFlags f)
+  : toListView(parent,name,f)
 {
   setup(false,true);
 }
@@ -1356,6 +1390,7 @@ QListViewItem *toResultView::createItem(QListViewItem *last,const QString &str)
 void toResultView::addItem(void)
 {
   MaxColDisp=toTool::globalConfig(CONF_MAX_COL_DISP,DEFAULT_MAX_COL_DISP).toInt();
+  Gridlines=!toTool::globalConfig(CONF_DISPLAY_GRIDLINES,DEFAULT_DISPLAY_GRIDLINES).isEmpty();
 
   try {
     if (Query&&!Query->eof()) {
@@ -1401,6 +1436,9 @@ void toResultView::query(const QString &sql,const toQList &param)
     setColumnAlignment(0,AlignRight);
   }
 
+  if (Filter)
+    Filter->startingQuery();
+
   try {
     Query=new toQuery(connection(),sql,param);
 
@@ -1576,4 +1614,3 @@ void toResultFilter::exportData(std::map<QCString,QString> &,const QCString &)
 void toResultFilter::importData(std::map<QCString,QString> &,const QCString &)
 {
 }
-
