@@ -70,6 +70,7 @@ public:
     };
     std::list<sessionID> Serials;
     bool Show;
+    QString OnlyDatabase;
   public:
 
     sessionFilter()
@@ -83,6 +84,8 @@ public:
     { Show=show; }
     bool show()
     { return Show; }
+    void onlyDatabase(const QString &db)
+    { OnlyDatabase=db; }
     void updateList(toResultLong *lst);
   };
   toSessionList(QWidget *parent)
@@ -132,6 +135,8 @@ class toSession : public toToolWidget {
 
 public:
   toSession(QWidget *parent,toConnection &connection);
+
+  virtual bool canHandle(toConnection &conn);
 public slots:
   void changeTab(QWidget *tab);
   void changeItem(QListViewItem *item);
@@ -151,4 +156,8 @@ public slots:
   void selectNone(void);
 };
 
+#ifdef TOEXTENDED_MYSQL
+#include "tosessionmysql.h"
+#endif
+
 #endif
