@@ -83,9 +83,12 @@ public:
   virtual QWidget *toolWindow(QWidget *parent,toConnection &connection)
   {
     if (Window)
-      Window->setFocus();
+      Window->show();
     else
       Window=new toSQLEdit(parent,connection);
+    
+    Window->raise();
+    Window->setFocus();
     Window->setIcon(QPixmap((const char **)tosqledit_xpm));
     return Window;
   }
@@ -512,7 +515,9 @@ toSQLTemplateItem::toSQLTemplateItem(toSQLTemplateItem *parent,
   : toTemplateItem(parent,JustLast(name))
 {
   Name=name;
-  setExpandable(true);
+  std::list<QCString> def=toSQL::range(Name+":");
+  if (def.begin()!=def.end())
+    setExpandable(true);
 }
 
 void toSQLTemplateItem::expand(void)
@@ -545,7 +550,7 @@ QString toSQLTemplateItem::allText(int) const
     toSQL::sqlMap defs=toSQL::definitions();
     if (defs.find(Name)==defs.end())
       return QString::null;
-    return toSQL::string(Name,toMainWidget()->currentConnection());
+    return toSQL::string(Name,toMainWidget()->currentConnection())+";";
   } catch(...) {
     return QString::null;
   }
