@@ -302,6 +302,7 @@ std::list<QString> toStorageDatafile::sql(void)
       str+=FilenameOrig;
       str+=QString::fromLatin1("' TO '");
       str+=Filename->text();
+      str+="'";
       toPush(ret,str);
     }
     if (InitialSize->value()!=InitialSizeOrig) {
@@ -457,7 +458,7 @@ toStorageDialog::toStorageDialog(toConnection &conn,const QString &tablespace,QW
     TablespaceOrig=tablespace;
     Tablespace->Modify=true;
     Default->setEnabled(false);
-    if (toShift(result)==QString::fromLatin1("DICTIONARY"))
+    if (toShift(result).toString()=="DICTIONARY")
       Tablespace->Dictionary->setChecked(true);
     else {
       Tablespace->DefaultStorage->setEnabled(false);
@@ -465,9 +466,9 @@ toStorageDialog::toStorageDialog(toConnection &conn,const QString &tablespace,QW
     }
     Tablespace->ExtentGroup->setEnabled(false);
 
-    Tablespace->Permanent->setChecked(toShift(result)==QString::fromLatin1("PERMANENT"));
-    Tablespace->Logging->setChecked(toShift(result)==QString::fromLatin1("LOGGING"));
-    Tablespace->Online->setChecked(toShift(result)==QString::fromLatin1("ONLINE"));
+    Tablespace->Permanent->setChecked(toShift(result).toString()=="PERMANENT");
+    Tablespace->Logging->setChecked(toShift(result).toString()=="LOGGING");
+    Tablespace->Online->setChecked(toShift(result).toString()=="ONLINE");
     Tablespace->OnlineOrig=Tablespace->Online->isChecked();
     Tablespace->PermanentOrig=Tablespace->Permanent->isChecked();
     Tablespace->LoggingOrig=Tablespace->Logging->isChecked();
@@ -836,7 +837,8 @@ void toStorage::windowActivated(QWidget *widget)
     if (!ToolMenu) {
       ToolMenu=new QPopupMenu(this);
       ToolMenu->insertItem(QPixmap((const char **)refresh_xpm),tr("&Refresh"),
-			   this,SLOT(refresh(void)),Key_F5);
+			   this,SLOT(refresh(void)),
+			   toKeySequence(tr("F5", "Storage|Refresh")));
       ToolMenu->insertSeparator();
       ToolMenu->insertItem(QPixmap((const char **)online_xpm),tr("Tablespace online"),
 			   this,SLOT(online()),0,TO_ID_ONLINE);
