@@ -1078,7 +1078,7 @@ void toTuningOverview::overviewQuery::run(void)
 
     res=toQuery::readQuery(*Parent.Connection,SQLOverviewBackground);
     QStringList back;
-    while(res.size()>0) {
+    while(!res.empty()) {
       tmp=toShift(res);
       if(tmp==QString::fromLatin1("DBW"))
 	tmp=QString::fromLatin1("DBWR");
@@ -1112,7 +1112,7 @@ void toTuningOverview::overviewQuery::run(void)
     double tot=0;
     double sql=0;
     res=toQuery::readQuery(*Parent.Connection,SQLOverviewSGA,val);
-    while(res.size()>0) {
+    while(!res.empty()) {
       QString nam=toShift(res);
       tmp=toShift(res);
       if (nam=="Database Buffers"||nam=="Redo Buffers")
@@ -1585,9 +1585,9 @@ void toTuning::windowActivated(QWidget *widget)
     if (!ToolMenu) {
       ToolMenu=new QPopupMenu(this);
       ToolMenu->insertItem(QPixmap((const char **)refresh_xpm),tr("&Refresh"),this,SLOT(refresh(void)),
-			   Key_F5);
+			   toKeySequence(tr("F5", "Tuning|Refresh")));
       ToolMenu->insertItem(tr("&Change Refresh"),Refresh,SLOT(setFocus(void)),
-			   Key_R+ALT);
+			   toKeySequence(tr("Alt+R", "Tuning|Change refresh")));
       toMainWidget()->menuBar()->insertItem(tr("&Tuning"),ToolMenu,-1,toToolMenuIndex());
     }
   } else {
@@ -1732,10 +1732,10 @@ toTuningFileIO::toTuningFileIO(QWidget *parent,const char *name,WFlags fl)
     TablespaceReads=new QGrid(2,Box);
     TablespaceTime=new QGrid(2,Box);
 
-    FileReads->setFixedWidth(viewport()->width()-50);
-    FileTime->setFixedWidth(viewport()->width()-50);
-    TablespaceReads->setFixedWidth(viewport()->width()-50);
-    TablespaceTime->setFixedWidth(viewport()->width()-50);
+    FileReads->setFixedWidth(viewport()->width()-30);
+    FileTime->setFixedWidth(viewport()->width()-30);
+    TablespaceReads->setFixedWidth(viewport()->width()-30);
+    TablespaceTime->setFixedWidth(viewport()->width()-30);
     changeCharts(0);
     CurrentStamp=0;
     connect(&Poll,SIGNAL(timeout()),this,SLOT(poll()));
@@ -1827,7 +1827,7 @@ void toTuningFileIO::saveSample(const QString &name,const QString &label,
 
     std::list<double> last=LastValues[name];
     std::list<double> dispVal;
-    if (last.size()>0) {
+    if (!last.empty()) {
       std::list<double>::iterator i=vals.begin();
       std::list<double>::iterator j=last.begin();
       while(i!=vals.end()&&j!=last.end()) {
@@ -1841,7 +1841,7 @@ void toTuningFileIO::saveSample(const QString &name,const QString &label,
     if (ReadsCharts.find(name)==ReadsCharts.end())
       allocCharts(name);
 
-    if (dispVal.size()>0) {
+    if (!dispVal.empty()) {
       toBarChart *chart=ReadsCharts[name];
       chart->addValues(dispVal,label);
     }
@@ -1943,10 +1943,10 @@ void toTuningFileIO::resizeEvent(QResizeEvent *e)
 {
   QScrollView::resizeEvent(e);
 
-  FileReads->setFixedWidth(viewport()->width()-50);
-  FileTime->setFixedWidth(viewport()->width()-50);
-  TablespaceReads->setFixedWidth(viewport()->width()-50);
-  TablespaceTime->setFixedWidth(viewport()->width()-50);
+  FileReads->setFixedWidth(viewport()->width()-30);
+  FileTime->setFixedWidth(viewport()->width()-30);
+  TablespaceReads->setFixedWidth(viewport()->width()-30);
+  TablespaceTime->setFixedWidth(viewport()->width()-30);
 }
 
 void toTuningFileIO::changeConnection(void)
